@@ -15,9 +15,11 @@ import (
 	"github.com/coreos/pkg/capnslog"
 	"github.com/coreos/pkg/flagutil"
 
-	"github.com/openshift/console/auth"
+	"github.com/openshift/console/pkg/auth"
+	"github.com/openshift/console/pkg/bridge"
 	"github.com/openshift/console/pkg/proxy"
-	"github.com/openshift/console/server"
+	"github.com/openshift/console/pkg/server"
+	"github.com/openshift/console/pkg/serverconfig"
 )
 
 var (
@@ -36,6 +38,9 @@ const (
 
 	// Well-known location of Alert Manager service for OpenShift. This is only accessible in-cluster.
 	openshiftAlertManagerHost = "alertmanager-main.openshift-monitoring.svc:9094"
+
+	// Well-known location of metering service for OpenShift. This is only accessible in-cluster.
+	openshiftMeteringHost = "reporting-operator.openshift-metering.svc:8080"
 )
 
 func main() {
@@ -45,7 +50,7 @@ func main() {
 	fs := flag.NewFlagSet("bridge", flag.ExitOnError)
 	fListen := fs.String("listen", "http://0.0.0.0:9000", "")
 
-	fBaseAddress := fs.String("base-address", "", "Format: <http | https>://domainOrIPAddress[:port]. Example: https://tectonic.example.com.")
+	fBaseAddress := fs.String("base-address", "", "Format: <http | https>://domainOrIPAddress[:port]. Example: https://openshift.example.com.")
 	fBasePath := fs.String("base-path", "/", "")
 	fConfig := fs.String("config", "", "The YAML config file.")
 
@@ -63,6 +68,8 @@ func main() {
 	fK8sMode := fs.String("k8s-mode", "in-cluster", "in-cluster | off-cluster")
 	fK8sModeOffClusterEndpoint := fs.String("k8s-mode-off-cluster-endpoint", "", "URL of the Kubernetes API server.")
 	fK8sModeOffClusterSkipVerifyTLS := fs.Bool("k8s-mode-off-cluster-skip-verify-tls", false, "DEV ONLY. When true, skip verification of certs presented by k8s API server.")
+	fK8sModeOffClusterPrometheus := fs.String("k8s-mode-off-cluster-prometheus", "", "DEV ONLY. URL of the cluster's Prometheus server.")
+	fK8sModeOffClusterAlertmanager := fs.String("k8s-mode-off-cluster-alertmanager", "", "DEV ONLY. URL of the cluster's AlertManager server.")
 
 	fK8sAuth := fs.String("k8s-auth", "service-account", "service-account | bearer-token | oidc | openshift")
 	fK8sAuthBearerToken := fs.String("k8s-auth-bearer-token", "", "Authorization token to send with proxied Kubernetes API requests.")
@@ -71,8 +78,7 @@ func main() {
 	fPublicDir := fs.String("public-dir", "./frontend/public/dist", "directory containing static web assets.")
 	fTlSCertFile := fs.String("tls-cert-file", "", "TLS certificate. If the certificate is signed by a certificate authority, the certFile should be the concatenation of the server's certificate followed by the CA's certificate.")
 	fTlSKeyFile := fs.String("tls-key-file", "", "The TLS certificate key.")
-	fCAFile := fs.String("ca-file", "", "PEM File containing trusted certificates of trusted CAs. If not present, the system's Root CAs will be used. Not required for in-cluster clients to determine the expiration date for /tectonic/certs endpoint.")
-	fTectonicVersion := fs.String("tectonic-version", "UNKNOWN", "The current tectonic system version, served at /version")
+	fCAFile := fs.String("ca-file", "", "PEM File containing trusted certificates of trusted CAs. If not present, the system's Root CAs will be used.")
 	fDexClientCertFile := fs.String("dex-client-cert-file", "", "PEM File containing certificates of dex client.")
 	fDexClientKeyFile := fs.String("dex-client-key-file", "", "PEM File containing certificate key of the dex client.")
 	fDexClientCAFile := fs.String("dex-client-ca-file", "", "PEM File containing trusted CAs for Dex client configuration. If blank, defaults to value of ca-file argument")
@@ -84,6 +90,9 @@ func main() {
 
 	fDexAPIHost := fs.String("dex-api-host", "", "Target host and port of the Dex API service.")
 	fBranding := fs.String("branding", "okd", "Console branding for the masthead logo and title. One of okd, openshift, ocp, online, dedicated, or azure. Defaults to okd.")
+	fCustomProductName := fs.String("custom-product-name", "", "Custom product name for console branding.")
+	fCustomLogoFile := fs.String("custom-logo-file", "", "Custom product image for console branding.")
+	fStatuspageID := fs.String("statuspage-id", "", "Unique ID assigned by statuspage.io page that provides status info.")
 	fDocumentationBaseURL := fs.String("documentation-base-url", "", "The base URL for documentation links.")
 	fGoogleTagManagerID := fs.String("google-tag-manager-id", "", "Google Tag Manager ID. External analytics are disabled if this is not set.")
 
@@ -100,14 +109,14 @@ func main() {
 	}
 
 	if *fConfig != "" {
-		if err := SetFlagsFromConfig(fs, *fConfig); err != nil {
+		if err := serverconfig.SetFlagsFromConfig(fs, *fConfig); err != nil {
 			log.Fatalf("Failed to load config: %v", err)
 		}
 	}
 
 	baseURL := &url.URL{}
 	if *fBaseAddress != "" {
-		baseURL = validateFlagIsURL("base-address", *fBaseAddress)
+		baseURL = bridge.ValidateFlagIsURL("base-address", *fBaseAddress)
 	}
 
 	if *fDexClientCAFile == "" {
@@ -115,7 +124,7 @@ func main() {
 	}
 
 	if !strings.HasPrefix(*fBasePath, "/") || !strings.HasSuffix(*fBasePath, "/") {
-		flagFatalf("base-path", "value must start and end with slash")
+		bridge.FlagFatalf("base-path", "value must start and end with slash")
 	}
 	baseURL.Path = *fBasePath
 
@@ -126,15 +135,27 @@ func main() {
 
 	logoutRedirect := &url.URL{}
 	if *fUserAuthLogoutRedirect != "" {
-		logoutRedirect = validateFlagIsURL("user-auth-logout-redirect", *fUserAuthLogoutRedirect)
+		logoutRedirect = bridge.ValidateFlagIsURL("user-auth-logout-redirect", *fUserAuthLogoutRedirect)
 	}
 
 	documentationBaseURL := &url.URL{}
 	if *fDocumentationBaseURL != "" {
 		if !strings.HasSuffix(*fDocumentationBaseURL, "/") {
-			flagFatalf("documentation-base-url", "value must end with slash")
+			bridge.FlagFatalf("documentation-base-url", "value must end with slash")
 		}
-		documentationBaseURL = validateFlagIsURL("documentation-base-url", *fDocumentationBaseURL)
+		documentationBaseURL = bridge.ValidateFlagIsURL("documentation-base-url", *fDocumentationBaseURL)
+	}
+
+	offClusterPrometheusURL := &url.URL{}
+	if *fK8sModeOffClusterPrometheus != "" && *fK8sMode == "off-cluster" {
+		offClusterPrometheusURL = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-prometheus", *fK8sModeOffClusterPrometheus)
+		offClusterPrometheusURL.Path = "/api"
+	}
+
+	offClusterAlertManagerURL := &url.URL{}
+	if *fK8sModeOffClusterAlertmanager != "" && *fK8sMode == "off-cluster" {
+		offClusterAlertManagerURL = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-alertmanager", *fK8sModeOffClusterAlertmanager)
+		offClusterAlertManagerURL.Path = "/api"
 	}
 
 	branding := *fBranding
@@ -149,16 +170,23 @@ func main() {
 	case "dedicated":
 	case "azure":
 	default:
-		flagFatalf("branding", "value must be one of okd, openshift, ocp, online, dedicated, or azure")
+		bridge.FlagFatalf("branding", "value must be one of okd, openshift, ocp, online, dedicated, or azure")
+	}
+
+	if *fCustomLogoFile != "" {
+		if _, err := os.Stat(*fCustomLogoFile); err != nil {
+			log.Fatalf("could not read logo file: %v", err)
+		}
 	}
 
 	srv := &server.Server{
 		PublicDir:            *fPublicDir,
-		TectonicVersion:      *fTectonicVersion,
 		BaseURL:              baseURL,
 		LogoutRedirect:       logoutRedirect,
-		TectonicCACertFile:   caCertFilePath,
 		Branding:             branding,
+		CustomProductName:    *fCustomProductName,
+		CustomLogoFile:       *fCustomLogoFile,
+		StatuspageID:         *fStatuspageID,
 		DocumentationBaseURL: documentationBaseURL,
 		GoogleTagManagerID:   *fGoogleTagManagerID,
 		LoadTestFactor:       *fLoadTestFactor,
@@ -213,11 +241,7 @@ func main() {
 	var k8sEndpoint *url.URL
 	switch *fK8sMode {
 	case "in-cluster":
-		host, port := os.Getenv("KUBERNETES_SERVICE_HOST"), os.Getenv("KUBERNETES_SERVICE_PORT")
-		if len(host) == 0 || len(port) == 0 {
-			log.Fatalf("unable to load in-cluster configuration, KUBERNETES_SERVICE_HOST and KUBERNETES_SERVICE_PORT must be defined")
-		}
-		k8sEndpoint = &url.URL{Scheme: "https", Host: host + ":" + port}
+		k8sEndpoint = &url.URL{Scheme: "https", Host: "kubernetes.default.svc"}
 
 		var err error
 		k8sCertPEM, err = ioutil.ReadFile(k8sInClusterCA)
@@ -249,40 +273,67 @@ func main() {
 			if err != nil {
 				log.Fatalf("failed to read service-ca.crt file: %v", err)
 			}
-			monitoringProxyRootCAs := x509.NewCertPool()
-			if !monitoringProxyRootCAs.AppendCertsFromPEM(serviceCertPEM) {
+			serviceProxyRootCAs := x509.NewCertPool()
+			if !serviceProxyRootCAs.AppendCertsFromPEM(serviceCertPEM) {
 				log.Fatalf("no CA found for Kubernetes services")
 			}
-			monitoringProxyTLSConfig := &tls.Config{RootCAs: monitoringProxyRootCAs}
+			serviceProxyTLSConfig := &tls.Config{RootCAs: serviceProxyRootCAs}
 			srv.PrometheusProxyConfig = &proxy.Config{
-				TLSClientConfig: monitoringProxyTLSConfig,
+				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftPrometheusHost, Path: "/api"},
 			}
 			srv.PrometheusTenancyProxyConfig = &proxy.Config{
-				TLSClientConfig: monitoringProxyTLSConfig,
+				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftPrometheusTenancyHost, Path: "/api"},
 			}
 			srv.AlertManagerProxyConfig = &proxy.Config{
-				TLSClientConfig: monitoringProxyTLSConfig,
+				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftAlertManagerHost, Path: "/api"},
 			}
+			srv.MeteringProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        &url.URL{Scheme: "https", Host: openshiftMeteringHost, Path: "/api"},
+			}
 		}
 
 	case "off-cluster":
-		k8sEndpoint = validateFlagIsURL("k8s-mode-off-cluster-endpoint", *fK8sModeOffClusterEndpoint)
-
+		k8sEndpoint = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-endpoint", *fK8sModeOffClusterEndpoint)
+		serviceProxyTLSConfig := &tls.Config{
+			InsecureSkipVerify: *fK8sModeOffClusterSkipVerifyTLS,
+		}
 		srv.K8sProxyConfig = &proxy.Config{
-			TLSClientConfig: &tls.Config{
-				InsecureSkipVerify: *fK8sModeOffClusterSkipVerifyTLS,
-			},
+			TLSClientConfig: serviceProxyTLSConfig,
 			HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 			Endpoint:        k8sEndpoint,
 		}
+
+		if offClusterPrometheusURL.String() != "" {
+			srv.PrometheusProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        offClusterPrometheusURL,
+			}
+			srv.PrometheusTenancyProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        offClusterPrometheusURL,
+			}
+		}
+
+		if offClusterAlertManagerURL.String() != "" {
+			srv.AlertManagerProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        offClusterAlertManagerURL,
+			}
+		}
+
 	default:
-		flagFatalf("k8s-mode", "must be one of: in-cluster, off-cluster")
+		bridge.FlagFatalf("k8s-mode", "must be one of: in-cluster, off-cluster")
 	}
 
 	apiServerEndpoint := *fK8sPublicEndpoint
@@ -298,8 +349,8 @@ func main() {
 
 	switch *fUserAuth {
 	case "oidc", "openshift":
-		validateFlagNotEmpty("base-address", *fBaseAddress)
-		validateFlagNotEmpty("user-auth-oidc-client-id", *fUserAuthOIDCClientID)
+		bridge.ValidateFlagNotEmpty("base-address", *fBaseAddress)
+		bridge.ValidateFlagNotEmpty("user-auth-oidc-client-id", *fUserAuthOIDCClientID)
 
 		if *fUserAuthOIDCClientSecret == "" && *fUserAuthOIDCClientSecretFile == "" {
 			fmt.Fprintln(os.Stderr, "Must provide either --user-auth-oidc-client-secret or --user-auth-oidc-client-secret-file")
@@ -333,11 +384,11 @@ func main() {
 			scopes = []string{"user:full"}
 			authSource = auth.AuthSourceOpenShift
 			if *fUserAuthOIDCIssuerURL != "" {
-				flagFatalf("user-auth-oidc-issuer-url", "cannot be used with --user-auth=\"openshift\"")
+				bridge.FlagFatalf("user-auth-oidc-issuer-url", "cannot be used with --user-auth=\"openshift\"")
 			}
 			userAuthOIDCIssuerURL = k8sEndpoint
 		} else {
-			userAuthOIDCIssuerURL = validateFlagIsURL("user-auth-oidc-issuer-url", *fUserAuthOIDCIssuerURL)
+			userAuthOIDCIssuerURL = bridge.ValidateFlagIsURL("user-auth-oidc-issuer-url", *fUserAuthOIDCIssuerURL)
 		}
 
 		if *fUserAuthOIDCClientSecretFile != "" {
@@ -391,34 +442,34 @@ func main() {
 	case "disabled":
 		log.Warningf("running with AUTHENTICATION DISABLED!")
 	default:
-		flagFatalf("user-auth", "must be one of: oidc, disabled")
+		bridge.FlagFatalf("user-auth", "must be one of: oidc, disabled")
 	}
 
 	switch *fK8sAuth {
 	case "service-account":
-		validateFlagIs("k8s-mode", *fK8sMode, "in-cluster")
+		bridge.ValidateFlagIs("k8s-mode", *fK8sMode, "in-cluster")
 		srv.StaticUser = &auth.User{
 			Token: k8sAuthServiceAccountBearerToken,
 		}
 	case "bearer-token":
-		validateFlagNotEmpty("k8s-auth-bearer-token", *fK8sAuthBearerToken)
+		bridge.ValidateFlagNotEmpty("k8s-auth-bearer-token", *fK8sAuthBearerToken)
 		srv.StaticUser = &auth.User{
 			Token: *fK8sAuthBearerToken,
 		}
 	case "oidc", "openshift":
-		validateFlagIs("user-auth", *fUserAuth, "oidc", "openshift")
+		bridge.ValidateFlagIs("user-auth", *fUserAuth, "oidc", "openshift")
 	default:
-		flagFatalf("k8s-mode", "must be one of: service-account, bearer-token, oidc")
+		bridge.FlagFatalf("k8s-mode", "must be one of: service-account, bearer-token, oidc")
 	}
 
-	listenURL := validateFlagIsURL("listen", *fListen)
+	listenURL := bridge.ValidateFlagIsURL("listen", *fListen)
 	switch listenURL.Scheme {
 	case "http":
 	case "https":
-		validateFlagNotEmpty("tls-cert-file", *fTlSCertFile)
-		validateFlagNotEmpty("tls-key-file", *fTlSKeyFile)
+		bridge.ValidateFlagNotEmpty("tls-cert-file", *fTlSCertFile)
+		bridge.ValidateFlagNotEmpty("tls-key-file", *fTlSKeyFile)
 	default:
-		flagFatalf("listen", "scheme must be one of: http, https")
+		bridge.FlagFatalf("listen", "scheme must be one of: http, https")
 	}
 
 	httpsrv := &http.Server{
@@ -435,46 +486,3 @@ func main() {
 		log.Fatal(httpsrv.ListenAndServe())
 	}
 }
-
-func validateFlagIsURL(name string, value string) *url.URL {
-	validateFlagNotEmpty(name, value)
-
-	ur, err := url.Parse(value)
-	if err != nil {
-		flagFatalf(name, "%v", err)
-	}
-
-	if ur == nil || ur.String() == "" || ur.Scheme == "" || ur.Host == "" {
-		flagFatalf(name, "malformed URL")
-	}
-
-	return ur
-}
-
-func validateFlagNotEmpty(name string, value string) string {
-	if value == "" {
-		flagFatalf(name, "value is required")
-	}
-
-	return value
-}
-
-func validateFlagIs(name string, value string, expectedValues ...string) string {
-	if len(expectedValues) != 1 {
-		for _, v := range expectedValues {
-			if v == value {
-				return value
-			}
-		}
-		flagFatalf(name, "value must be one of %s, not %s", expectedValues, value)
-	}
-	if value != expectedValues[0] {
-		flagFatalf(name, "value must be %s, not %s", expectedValues[0], value)
-	}
-
-	return value
-}
-
-func flagFatalf(name string, format string, a ...interface{}) {
-	log.Fatalf("Invalid flag: %s, error: %s", name, fmt.Sprintf(format, a...))
-}
