@@ -1,27 +1,42 @@
-/* eslint-disable no-undef */
 import * as React from 'react';
 import * as _ from 'lodash-es';
-import { Icon } from 'patternfly-react';
 import { Link } from 'react-router-dom';
+import * as classNames from 'classnames';
+import { sortable } from '@patternfly/react-table';
 
-// eslint-disable-next-line no-unused-vars
-import { K8sResourceKindReference, referenceFor, K8sResourceKind } from '../module/k8s';
-import { cloneBuild, formatBuildDuration, BuildPhase, getBuildNumber } from '../module/k8s/builds';
-import { ColHead, DetailsPage, List, ListHeader, ListPage } from './factory';
-import { errorModal } from './modals';
-import { BuildHooks, BuildStrategy, Kebab, SectionHeading, history, navFactory, ResourceKebab, ResourceLink, resourceObjPath, ResourceSummary, Timestamp, AsyncComponent, resourcePath, StatusIcon } from './utils';
+import { Status } from '@console/shared';
+import { K8sResourceKindReference, referenceFor, K8sResourceKind, k8sPatch, K8sKind } from '../module/k8s';
+import { cloneBuild, formatBuildDuration, getBuildNumber } from '../module/k8s/builds';
+import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { errorModal, confirmModal } from './modals';
+import {
+  AsyncComponent,
+  BuildHooks,
+  BuildStrategy,
+  history,
+  humanizeCpuCores,
+  humanizeDecimalBytes,
+  Kebab,
+  KebabAction,
+  navFactory,
+  ResourceKebab,
+  ResourceLink,
+  resourceObjPath,
+  resourcePath,
+  ResourceSummary,
+  SectionHeading,
+  Timestamp,
+} from './utils';
 import { BuildPipeline, BuildPipelineLogLink } from './build-pipeline';
-import { breadcrumbsForOwnerRefs } from './utils/breadcrumbs';
 import { fromNow } from './utils/datetime';
 import { BuildLogs } from './build-logs';
 import { ResourceEventStream } from './events';
-import { Line, requirePrometheus } from './graphs';
+import { Area, requirePrometheus } from './graphs';
+import { BuildModel } from '../models';
 
 const BuildsReference: K8sResourceKindReference = 'Build';
 
-const { common, EditEnvironment } = Kebab.factory;
-
-const cloneBuildAction = (kind, build) => ({
+const CloneBuildAction: KebabAction = (kind: K8sKind, build: K8sResourceKind) => ({
   label: 'Rebuild',
   callback: () => cloneBuild(build).then(clone => {
     history.push(resourceObjPath(clone, referenceFor(clone)));
@@ -29,12 +44,42 @@ const cloneBuildAction = (kind, build) => ({
     const error = err.message;
     errorModal({ error });
   }),
+  accessReview: {
+    group: kind.apiGroup,
+    resource: kind.plural,
+    subresource: 'instantiate',
+    name: build.metadata.name,
+    namespace: build.metadata.namespace,
+    verb: 'create',
+  },
+});
+
+const CancelAction: KebabAction = (kind: K8sKind, build: K8sResourceKind) => ({
+  label: 'Cancel Build',
+  hidden: build.status.phase !== 'Running' && build.status.phase !== 'Pending' && build.status.phase !== 'New',
+  callback: () => confirmModal({
+    title: 'Cancel build',
+    message: 'Are you sure you want to cancel this build?',
+    btnText: 'Yes, cancel',
+    cancelText: 'No, don\'t cancel',
+    executeFn: () => k8sPatch(kind,
+      build,
+      [{ op: 'add', path: '/status/cancelled', value: true }]),
+  }),
+  accessReview: {
+    group: kind.apiGroup,
+    resource: kind.plural,
+    name: build.metadata.name,
+    namespace: build.metadata.namespace,
+    verb: 'patch',
+  },
 });
 
 const menuActions = [
-  cloneBuildAction,
-  EditEnvironment,
-  ...common,
+  CloneBuildAction,
+  CancelAction,
+  ...Kebab.getExtensionsActionsForKind(BuildModel),
+  ...Kebab.factory.common,
 ];
 
 export enum BuildStrategyType {
@@ -44,23 +89,6 @@ export enum BuildStrategyType {
   Source = 'Source',
 }
 
-export const BuildPhaseIcon: React.SFC<BuildPhaseIconProps> = ({build}) => {
-  const {status: {phase}} = build;
-  switch (phase) {
-    case BuildPhase.Running:
-      return <span className="fa fa-spin fa-refresh" aria-hidden="true" />;
-    case BuildPhase.Complete:
-      return <Icon type="pf" name="ok" />;
-    case BuildPhase.Failed:
-    case BuildPhase.Error:
-      return <Icon type="pf" name="error-circle-o" />;
-    case BuildPhase.Cancelled:
-      return <Icon type="fa" name="ban" />;
-    default:
-      return <Icon type="fa" name="clock-o" />;
-  }
-};
-
 export const BuildLogLink = ({build}) => {
   const {metadata: {name, namespace}} = build;
   const isPipeline = _.get(build, 'spec.strategy.type') === BuildStrategyType.JenkinsPipeline;
@@ -91,17 +119,31 @@ const BuildGraphs = requirePrometheus(({build}) => {
 
   return <React.Fragment>
     <div className="row">
-      <div className="col-md-4">
-        <Line title="Memory Usage" namespace={namespace} query={`pod_name:container_memory_usage_bytes:sum{pod_name='${podName}',container_name='',namespace='${namespace}'}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Memory Usage"
+          humanize={humanizeDecimalBytes}
+          namespace={namespace}
+          query={`sum(container_memory_working_set_bytes{pod='${podName}',namespace='${namespace}',container=''}) BY (pod, namespace)`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="CPU Usage" namespace={namespace} query={`pod_name:container_cpu_usage:sum{pod_name='${podName}',container_name='',namespace='${namespace}'}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="CPU Usage"
+          humanize={humanizeCpuCores}
+          namespace={namespace}
+          query={`pod_name:container_cpu_usage:sum{pod_name='${podName}',container_name='',namespace='${namespace}'}`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="Filesystem" namespace={namespace} query={`pod_name:container_fs_usage_bytes:sum{pod_name='${podName}',container_name='',namespace='${namespace}'}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Filesystem"
+          humanize={humanizeDecimalBytes}
+          namespace={namespace}
+          query={`pod_name:container_fs_usage_bytes:sum{pod_name='${podName}',container_name='',namespace='${namespace}'}`}
+        />
       </div>
     </div>
-
     <br />
   </React.Fragment>;
 });
@@ -133,7 +175,7 @@ export const BuildsDetails: React.SFC<BuildsDetailsProps> = ({ obj: build }) =>
         <div className="col-sm-6">
           <BuildStrategy resource={build}>
             <dt>Status</dt>
-            <dd>{build.status.phase}</dd>
+            <dd><Status status={build.status.phase} /></dd>
             {logSnippet && <dt>Log Snippet</dt>}
             {logSnippet && <dd><pre>{logSnippet}</pre></dd>}
             {message && <dt>Reason</dt>}
@@ -199,41 +241,75 @@ const pages = [
 export const BuildsDetailsPage: React.SFC<BuildsDetailsPageProps> = props =>
   <DetailsPage
     {...props}
-    breadcrumbsFor={obj => breadcrumbsForOwnerRefs(obj).concat({
-      name: 'Build Details',
-      path: props.match.url,
-    })}
     kind={BuildsReference}
     menuActions={menuActions}
     pages={pages} />;
 BuildsDetailsPage.displayName = 'BuildsDetailsPage';
 
-const BuildsHeader = props => <ListHeader>
-  <ColHead {...props} className="col-sm-3 col-xs-6" sortField="metadata.name">Name</ColHead>
-  <ColHead {...props} className="col-sm-3 col-xs-6" sortField="metadata.namespace">Namespace</ColHead>
-  <ColHead {...props} className="col-sm-3 hidden-xs" sortField="status.phase">Status</ColHead>
-  <ColHead {...props} className="col-sm-3 hidden-xs" sortField="metadata.creationTimestamp">Created</ColHead>
-</ListHeader>;
+const tableColumnClasses = [
+  classNames('col-sm-3', 'col-xs-6'),
+  classNames('col-sm-3', 'col-xs-6'),
+  classNames('col-sm-3', 'hidden-xs'),
+  classNames('col-sm-3', 'hidden-xs'),
+  Kebab.columnClass,
+];
 
-const BuildsRow: React.SFC<BuildsRowProps> = ({ obj }) => <div className="row co-resource-list__item">
-  <div className="col-sm-3 col-xs-6">
-    <ResourceLink kind={BuildsReference} name={obj.metadata.name} namespace={obj.metadata.namespace} title={obj.metadata.name} />
-  </div>
-  <div className="col-sm-3 col-xs-6 co-break-word">
-    <ResourceLink kind="Namespace" name={obj.metadata.namespace} />
-  </div>
-  <div className="col-sm-3 hidden-xs">
-    <StatusIcon status={obj.status.phase} />
-  </div>
-  <div className="col-sm-3 hidden-xs">
-    {fromNow(obj.metadata.creationTimestamp)}
-  </div>
-  <div className="dropdown-kebab-pf">
-    <ResourceKebab actions={menuActions} kind={BuildsReference} resource={obj} />
-  </div>
-</div>;
+const BuildsTableHeader = () => {
+  return [
+    {
+      title: 'Name', sortField: 'metadata.name', transforms: [sortable],
+      props: { className: tableColumnClasses[0] },
+    },
+    {
+      title: 'Namespace', sortField: 'metadata.namespace', transforms: [sortable],
+      props: { className: tableColumnClasses[1] },
+    },
+    {
+      title: 'Status', sortField: 'status.phase', transforms: [sortable],
+      props: { className: tableColumnClasses[2] },
+    },
+    {
+      title: 'Created', sortField: 'metadata.creationTimestamp', transforms: [sortable],
+      props: { className: tableColumnClasses[3] },
+    },
+    {
+      title: '', props: { className: tableColumnClasses[4] },
+    },
+  ];
+};
+BuildsTableHeader.displayName = 'BuildsTableHeader';
+
+const BuildsTableRow: React.FC<BuildsTableRowProps> = ({obj, index, key, style}) => {
+  return (
+    <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
+      <TableData className={tableColumnClasses[0]}>
+        <ResourceLink kind={BuildsReference} name={obj.metadata.name} namespace={obj.metadata.namespace} title={obj.metadata.name} />
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[1], 'co-break-word')}>
+        <ResourceLink kind="Namespace" name={obj.metadata.namespace} />
+      </TableData>
+      <TableData className={tableColumnClasses[2]}>
+        <Status status={obj.status.phase} />
+      </TableData>
+      <TableData className={tableColumnClasses[3]}>
+        {fromNow(obj.metadata.creationTimestamp)}
+      </TableData>
+      <TableData className={tableColumnClasses[4]}>
+        <ResourceKebab actions={menuActions} kind={BuildsReference} resource={obj} />
+      </TableData>
+    </TableRow>
+  );
+};
+BuildsTableRow.displayName = 'BuildsTableRow';
+type BuildsTableRowProps = {
+  obj: K8sResourceKind;
+  index: number;
+  key?: string;
+  style: object;
+};
+
+export const BuildsList: React.SFC = props => <Table {...props} aria-label="Builds" Header={BuildsTableHeader} Row={BuildsTableRow} virtualize />;
 
-export const BuildsList: React.SFC = props => <List {...props} Header={BuildsHeader} Row={BuildsRow} />;
 BuildsList.displayName = 'BuildsList';
 
 export const buildPhase = build => build.status.phase;
@@ -260,10 +336,6 @@ export const BuildsPage: React.SFC<BuildsPageProps> = props =>
   />;
 BuildsPage.displayName = 'BuildsListPage';
 
-export type BuildsRowProps = {
-  obj: any,
-};
-
 export type BuildsDetailsProps = {
   obj: any,
 };
@@ -277,8 +349,3 @@ export type BuildsPageProps = {
 export type BuildsDetailsPageProps = {
   match: any,
 };
-
-export type BuildPhaseIconProps = {
-  build: K8sResourceKind
-};
-/* eslint-enable no-undef */
