@@ -1,7 +1,9 @@
 import * as React from 'react';
 
 import { ImpersonateNotifier } from './impersonate-notifier';
+import { KubeAdminNotifier } from './kube-admin-notifier';
 
 export const GlobalNotifications = () => <div className="co-global-notifications">
+  <KubeAdminNotifier />
   <ImpersonateNotifier />
 </div>;
