@@ -1,17 +1,10 @@
 import * as _ from 'lodash-es';
 import * as React from 'react';
+import * as classnames from 'classnames';
 import { Link } from 'react-router-dom';
 
-import { SafetyFirst } from '../safety-first';
 import { coFetchJSON } from '../../co-fetch';
-import { prometheusBasePath, prometheusTenancyBasePath } from './index';
-
-const colors = {
-  ok: 'rgb(57,200,143)',
-  warn: 'rgb(245,178,83)',
-  error: 'rgb(213,69,89)',
-};
-
+import { PROMETHEUS_BASE_PATH, PROMETHEUS_TENANCY_BASE_PATH } from '.';
 
 export const errorStatus = err => {
   if (_.get(err.response, 'ok') === false) {
@@ -31,7 +24,7 @@ export const errorStatus = err => {
 
 const fetchQuery = (q, long, namespace) => {
   const nsParam = namespace ? `&namespace=${encodeURIComponent(namespace)}` : '';
-  const basePath = namespace ? prometheusTenancyBasePath : prometheusBasePath;
+  const basePath = namespace ? PROMETHEUS_TENANCY_BASE_PATH : PROMETHEUS_BASE_PATH;
   return coFetchJSON(`${basePath}/api/v1/query?query=${encodeURIComponent(q)}${nsParam}`)
     .then(res => {
       const short = parseInt(_.get(res, 'data.result[0].value[1]'), 10) || 0;
@@ -45,7 +38,7 @@ const fetchQuery = (q, long, namespace) => {
 };
 
 /** @augments {React.Component<{fetch?: () => Promise<any>, query?: string, title: string, href?: string, rel?: string, target?: string}}>} */
-export class Status extends SafetyFirst {
+export class Status extends React.Component {
   constructor(props) {
     super(props);
     this.interval = null;
@@ -95,37 +88,29 @@ export class Status extends SafetyFirst {
   }
 
   componentWillUnmount() {
-    super.componentWillUnmount();
     clearInterval(this.interval);
   }
 
   render() {
     const title = this.props.title;
     const { short, long, status } = this.state;
-    let color = colors.gray;
-    if (status === 'OK') {
-      color = colors.ok;
-    } else if (status === 'ERROR') {
-      color = colors.error;
-    } else if (status === 'WARN') {
-      color = colors.warn;
-    }
+    const shortStatusClassName = classnames('graph-status__short', {
+      'graph-status__short--ok': status === 'OK',
+      'graph-status__short--warn': status === 'WARN',
+      'graph-status__short--error': status === 'ERROR',
+    });
 
-    const defaultStyle = {
-      marginBottom: '30px',
-    };
-
-    const statusElem = <div className="graph-wrapper" style={Object.assign({}, defaultStyle, this.style)} >
+    const statusElem = <div className="graph-wrapper graph-wrapper--title-center graph-wrapper--status">
       { title && <h5 className="graph-title">{title}</h5> }
-      <div className="text-center">
-        <h1 style={{color, fontSize: 26, marginBottom: 2}}>{short}</h1>
-        <div className="text-muted" style={{fontSize: 14, lineHeight: 1.3}}>{long}</div>
+      <div className="graph-status">
+        <h1 className={shortStatusClassName}>{short}</h1>
+        <div className="graph-status--long">{long}</div>
       </div>
     </div>;
-    const props = _.pick(this.props, ['rel', 'target', 'to']);
-    if (_.isEmpty(props)) {
+    const linkProps = _.pick(this.props, ['rel', 'target', 'to']);
+    if (_.isEmpty(linkProps)) {
       return statusElem;
     }
-    return <Link {...props} style={{textDecoration: 'none'}}>{statusElem}</Link>;
+    return <Link {...linkProps} className="graph-status__link">{statusElem}</Link>;
   }
 }
