@@ -2,6 +2,7 @@ import * as _ from 'lodash-es';
 import * as React from 'react';
 import * as PropTypes from 'prop-types';
 import { Base64 } from 'js-base64';
+import { Alert } from '@patternfly/react-core';
 
 import { k8sPatch, k8sCreate } from '../../module/k8s';
 import { SecretModel } from '../../models';
@@ -177,7 +178,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
           Specify default credentials to be used to authenticate and download containers within this namespace. These credentials will be the default unless a pod references a specific pull secret.
         </p>
 
-        {existingData.invalidData && <p className="alert alert-danger"><span className="pficon pficon-error-circle-o"></span>A default pull secret exists, but can&rsquo;t be parsed. Saving this will overwrite it.</p>}
+        {existingData.invalidData && <Alert isInline className="co-alert" variant="danger" title="Overwriting default pull secret">A default pull secret exists, but can't be parsed. Saving this will overwrite it.</Alert>}
 
         <div className="row co-m-form-row">
           <div className="col-xs-3">
@@ -197,7 +198,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
               <ResourceIcon kind="Secret" />
                 &nbsp;{_.get(pullSecret, 'metadata.name')}
             </div> : <div className="col-xs-9">
-              <input type="text" className="form-control" id="namespace-pull-secret-name" aria-describedby="namespace-pull-secret-name-help" required />
+              <input type="text" className="pf-c-form-control" id="namespace-pull-secret-name" aria-describedby="namespace-pull-secret-name-help" required />
               <p className="help-block text-muted" id="namespace-pull-secret-name-help">Friendly name to help you manage this in the future</p>
             </div>
           }
@@ -234,7 +235,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
               <label htmlFor="namespace-pull-secret-address">Registry Address</label>
             </div>
             <div className="col-xs-9">
-              <input type="text" className="form-control" id="namespace-pull-secret-address" defaultValue={existingData.address} placeholder="quay.io" required />
+              <input type="text" className="pf-c-form-control" id="namespace-pull-secret-address" defaultValue={existingData.address} placeholder="quay.io" required />
             </div>
           </div>
           <div className="row co-m-form-row">
@@ -242,7 +243,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
               <label htmlFor="namespace-pull-secret-email">Email Address</label>
             </div>
             <div className="col-xs-9">
-              <input type="email" className="form-control" defaultValue={existingData.email} id="namespace-pull-secret-email" aria-describedby="namespace-pull-secret-email-help" />
+              <input type="email" className="pf-c-form-control" defaultValue={existingData.email} id="namespace-pull-secret-email" aria-describedby="namespace-pull-secret-email-help" />
               <p className="help-block text-muted" id="namespace-pull-secret-email-help">Optional, depending on registry provider</p>
             </div>
           </div>
@@ -251,7 +252,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
               <label htmlFor="namespace-pull-secret-username">Username</label>
             </div>
             <div className="col-xs-9">
-              <input type="text" defaultValue={existingData.username} className="form-control" id="namespace-pull-secret-username" required />
+              <input type="text" defaultValue={existingData.username} className="pf-c-form-control" id="namespace-pull-secret-username" required />
             </div>
           </div>
           <div className="row co-m-form-row">
@@ -259,7 +260,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
               <label htmlFor="namespace-pull-secret-password">Password</label>
             </div>
             <div className="col-xs-9">
-              <input type="password" defaultValue={existingData.password} className="form-control" id="namespace-pull-secret-password" required />
+              <input type="password" defaultValue={existingData.password} className="pf-c-form-control" id="namespace-pull-secret-password" required />
             </div>
           </div>
         </div> }
@@ -276,7 +277,7 @@ class ConfigureNamespacePullSecret extends PromiseComponent {
           </div>
           { this.state.invalidJson || existingData.invalidJson && <div className="row co-m-form-row">
             <div className="col-xs-9 col-sm-offset-3">
-              <div className="alert alert-danger"><span className="pficon pficon-error-circle-o"></span>Invalid format. Uploaded file is not properly formatted json.</div>
+              <Alert isInline className="co-alert" variant="danger" title="Invalid JSON">The uploaded file is not properly-formatted JSON.</Alert>
             </div>
           </div> }
           { this.state.fileData &&<div className="row co-m-form-row">
