@@ -1,28 +1,40 @@
-import * as _ from 'lodash-es';
 import * as classNames from 'classnames';
+import * as _ from 'lodash-es';
 import { murmur3 } from 'murmurhash-js';
+import { Alert , ActionGroup, Button, Tooltip } from '@patternfly/react-core';
+import { sortable } from '@patternfly/react-table';
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { connect } from 'react-redux';
 import { Link, Redirect, Route, Switch } from 'react-router-dom';
+import {
+  BanIcon,
+  BellIcon,
+  BellSlashIcon,
+  HourglassHalfIcon,
+  MinusCircleIcon,
+  OutlinedBellIcon,
+  PlusCircleIcon,
+} from '@patternfly/react-icons';
 
+import * as k8sActions from '../actions/k8s';
+import * as UIActions from '../actions/ui';
 import { coFetchJSON } from '../co-fetch';
-import k8sActions from '../module/k8s/k8s-actions';
-import { alertState, AlertStates, connectToURLs, MonitoringRoutes, silenceState, SilenceStates } from '../monitoring';
+import { alertState, AlertStates, connectToURLs, MonitoringRoutes, silenceState, SilenceStates } from '../reducers/monitoring';
 import store from '../redux';
-import { UIActions } from '../ui/ui-actions';
-import { ColHead, List, ListHeader, ResourceRow, TextFilter } from './factory';
-import { QueryBrowser } from './graphs';
+import { ResourceRow, Table, TableData, TableRow, TextFilter } from './factory';
 import { confirmModal } from './modals';
+import { graphStateToProps, QueryBrowserPage, ToggleGraph } from './monitoring/metrics';
+import { Labels, QueryBrowser } from './monitoring/query-browser';
 import { CheckBoxes } from './row-filter';
-import { SafetyFirst } from './safety-first';
 import { formatPrometheusDuration } from './utils/datetime';
 import { withFallback } from './utils/error-boundary';
-import { Tooltip } from './utils/tooltip';
+import { AlertManagerYAMLEditorWrapper } from './monitoring/alert-manager-yaml-editor';
 import {
   ActionsMenu,
   ButtonBar,
   ExternalLink,
+  Firehose,
   getURLSearchParams,
   history,
   Kebab,
@@ -31,25 +43,26 @@ import {
   StatusBox,
   Timestamp,
 } from './utils';
+import { GreenCheckCircleIcon } from '@console/shared';
 
 const AlertResource = {
   kind: 'Alert',
   label: 'Alert',
-  path: '/monitoring/alerts',
+  plural: '/monitoring/alerts',
   abbr: 'AL',
 };
 
 const AlertRuleResource = {
   kind: 'AlertRule',
   label: 'Alerting Rule',
-  path: '/monitoring/alertrules',
+  plural: '/monitoring/alertrules',
   abbr: 'AR',
 };
 
 const SilenceResource = {
   kind: 'Silence',
   label: 'Silence',
-  path: '/monitoring/silences',
+  plural: '/monitoring/silences',
   abbr: 'SL',
 };
 
@@ -62,8 +75,8 @@ const buildNotFiringAlert = (rule: Rule): Alert => ({
   state: AlertStates.NotFiring,
 });
 
-const alertURL = (alert, ruleID) => `${AlertResource.path}/${ruleID}?${labelsToParams(alert.labels)}`;
-const ruleURL = rule => `${AlertRuleResource.path}/${_.get(rule, 'id')}`;
+const alertURL = (alert, ruleID) => `${AlertResource.plural}/${ruleID}?${labelsToParams(alert.labels)}`;
+const ruleURL = rule => `${AlertRuleResource.plural}/${_.get(rule, 'id')}`;
 
 const alertDescription = alert => {
   const {annotations = {}, labels = {}} = alert;
@@ -84,7 +97,7 @@ const refreshPoller = key => {
 
 const silenceAlert = alert => ({
   label: 'Silence Alert',
-  href: `${SilenceResource.path}/~new?${labelsToParams(alert.labels)}`,
+  href: `${SilenceResource.plural}/~new?${labelsToParams(alert.labels)}`,
 });
 
 const viewAlertRule = alert => ({
@@ -94,7 +107,7 @@ const viewAlertRule = alert => ({
 
 const editSilence = silence => ({
   label: silenceState(silence) === SilenceStates.Expired ? 'Recreate Silence' : 'Edit Silence',
-  href: `${SilenceResource.path}/${silence.id}/edit`,
+  href: `${SilenceResource.plural}/${silence.id}/edit`,
 });
 
 const cancelSilence = (silence) => ({
@@ -103,7 +116,7 @@ const cancelSilence = (silence) => ({
     title: 'Expire Silence',
     message: 'Are you sure you want to expire this silence?',
     btnText: 'Expire Silence',
-    executeFn: () => coFetchJSON.delete(`${(window as any).SERVER_FLAGS.alertManagerBaseURL}/api/v1/silence/${silence.id}`)
+    executeFn: () => coFetchJSON.delete(`${window.SERVER_FLAGS.alertManagerBaseURL}/api/v1/silence/${silence.id}`)
       .then(() => refreshPoller('silences')),
   }),
 });
@@ -114,7 +127,7 @@ const silenceMenuActions = (silence) => silenceState(silence) === SilenceStates.
 
 const SilenceKebab = ({silence}) => <Kebab options={silenceMenuActions(silence)} />;
 
-const SilenceActionsMenu = ({silence}) => <div className="co-actions">
+const SilenceActionsMenu = ({silence}) => <div className="co-actions" data-test-id="details-actions">
   <ActionsMenu actions={silenceMenuActions(silence)} />
 </div>;
 
@@ -127,22 +140,22 @@ const AlertState: React.SFC<AlertStateProps> = ({state}) => {
   if (state === AlertStates.NotFiring) {
     return <span className="text-muted">Not Firing</span>;
   }
-  const klass = {
-    [AlertStates.Firing]: 'fa fa-fw fa-bell alert-firing',
-    [AlertStates.Silenced]: 'fa fa-fw fa-bell-slash text-muted',
-    [AlertStates.Pending]: 'fa fa-fw fa-bell-o alert-pending',
+  const icon = {
+    [AlertStates.Firing]: <BellIcon className="alert-firing" />,
+    [AlertStates.Silenced]: <BellSlashIcon className="text-muted" />,
+    [AlertStates.Pending]: <OutlinedBellIcon className="alert-pending" />,
   }[state];
-  return klass ? <React.Fragment><i className={klass} aria-hidden="true"></i> {_.startCase(state)}</React.Fragment> : null;
+  return icon ? <React.Fragment>{icon} {_.startCase(state)}</React.Fragment> : null;
 };
 
 const SilenceState = ({silence}) => {
   const state = silenceState(silence);
-  const klass = {
-    [SilenceStates.Active]: 'pficon pficon-ok fa-fw',
-    [SilenceStates.Pending]: 'fa fa-fw fa-hourglass-half monitoring-state-icon--pending',
-    [SilenceStates.Expired]: 'fa fa-fw fa-ban text-muted',
+  const icon = {
+    [SilenceStates.Active]: <GreenCheckCircleIcon />,
+    [SilenceStates.Pending]: <HourglassHalfIcon className="monitoring-state-icon--pending" />,
+    [SilenceStates.Expired]: <BanIcon className="text-muted" data-test-id="ban-icon" />,
   }[state];
-  return klass ? <React.Fragment><i className={klass} aria-hidden="true"></i> {_.startCase(state)}</React.Fragment> : null;
+  return icon ? <React.Fragment>{icon} {_.startCase(state)}</React.Fragment> : null;
 };
 
 const StateTimestamp = ({text, timestamp}) => <div className="text-muted monitoring-timestamp">
@@ -169,26 +182,25 @@ const Label = ({k, v}) => <div className="co-m-label co-m-label--expand" key={k}
   <span className="co-m-label__value">{v}</span>
 </div>;
 
-const graphStateToProps = ({UI}) => ({hideGraphs: !!UI.getIn(['monitoring', 'hideGraphs'])});
+const queryBrowserURL = query => `/monitoring/query-browser?query0=${encodeURIComponent(query)}`;
 
-const ToggleGraph_ = ({hideGraphs, toggle}) => {
-  const iconClass = `fa fa-${hideGraphs ? 'line-chart' : 'compress'}`;
-  return <button type="button" className="btn btn-link" onClick={toggle}>
-    {hideGraphs ? 'Show' : 'Hide'} Graph <i className={iconClass} aria-hidden="true" />
-  </button>;
-};
-const ToggleGraph = connect(graphStateToProps, {toggle: UIActions.toggleMonitoringGraphs})(ToggleGraph_);
-
-const Graph_ = ({hideGraphs, metric = undefined, numSamples, rule}) => {
+const Graph_ = ({hideGraphs, filterLabels = undefined, rule}) => {
   if (hideGraphs) {
     return null;
   }
   const {duration = 0, query = ''} = rule || {};
 
   // 3 times the rule's duration, but not less than 30 minutes
-  const timeSpan = Math.max(3 * duration, 30 * 60) * 1000;
+  const timespan = Math.max(3 * duration, 30 * 60) * 1000;
 
-  return <QueryBrowser metric={metric} numSamples={numSamples} query={query} timeSpan={timeSpan} timeout="5s" />;
+  const GraphLink = () => query ? <Link to={queryBrowserURL(query)}>View in Metrics</Link> : null;
+
+  return <QueryBrowser
+    defaultTimespan={timespan}
+    filterLabels={filterLabels}
+    GraphLink={GraphLink}
+    queries={[query]}
+  />;
 };
 const Graph = connect(graphStateToProps)(Graph_);
 
@@ -225,20 +237,19 @@ const AlertsDetailsPage = withFallback(connect(alertStateToProps)((props: Alerts
     <StatusBox data={alert} label={AlertResource.label} loaded={loaded} loadError={loadError}>
       <div className="co-m-nav-title co-m-nav-title--detail">
         <h1 className="co-m-pane__heading">
-          <div className="co-m-pane__name co-resource-item"><MonitoringResourceIcon className="co-m-resource-icon--lg" resource={AlertResource} />{alertname}</div>
-          {(state === AlertStates.Firing || state === AlertStates.Pending) && <div className="co-actions">
+          <div className="co-resource-item"><MonitoringResourceIcon className="co-m-resource-icon--lg" resource={AlertResource} />{alertname}</div>
+          {(state === AlertStates.Firing || state === AlertStates.Pending) && <div className="co-actions" data-test-id="details-actions">
             <ActionsMenu actions={[silenceAlert(alert)]} />
           </div>}
         </h1>
       </div>
       <div className="co-m-pane__body">
-        <SectionHeading text="Alert Overview">
-          {state !== AlertStates.NotFiring && <ToggleGraph />}
-        </SectionHeading>
+        {state !== AlertStates.NotFiring && <ToggleGraph />}
+        <SectionHeading text="Alert Overview" />
         <div className="co-m-pane__body-group">
           <div className="row">
             <div className="col-sm-12">
-              {state !== AlertStates.NotFiring && <Graph metric={labels} numSamples={600} rule={rule} />}
+              {state !== AlertStates.NotFiring && <Graph filterLabels={labels} rule={rule} />}
             </div>
           </div>
           <div className="row">
@@ -266,7 +277,7 @@ const AlertsDetailsPage = withFallback(connect(alertStateToProps)((props: Alerts
                 <dd>
                   <div className="co-resource-item">
                     <MonitoringResourceIcon resource={AlertRuleResource} />
-                    <Link to={ruleURL(rule)} className="co-resource-item__resource-name">{_.get(rule, 'name')}</Link>
+                    <Link to={ruleURL(rule)} data-test-id="alert-detail-resource-link" className="co-resource-item__resource-name">{_.get(rule, 'name')}</Link>
                   </div>
                 </dd>
               </dl>
@@ -343,7 +354,7 @@ const AlertRulesDetailsPage = withFallback(connect(ruleStateToProps)((props: Ale
     <StatusBox data={rule} label={AlertRuleResource.label} loaded={loaded} loadError={loadError}>
       <div className="co-m-nav-title co-m-nav-title--detail">
         <h1 className="co-m-pane__heading">
-          <div className="co-m-pane__name co-resource-item"><MonitoringResourceIcon className="co-m-resource-icon--lg" resource={AlertRuleResource} />{name}</div>
+          <div className="co-resource-item"><MonitoringResourceIcon className="co-m-resource-icon--lg" resource={AlertRuleResource} />{name}</div>
         </h1>
       </div>
       <div className="co-m-pane__body">
@@ -372,7 +383,11 @@ const AlertRulesDetailsPage = withFallback(connect(ruleStateToProps)((props: Ale
                   <dd>{formatPrometheusDuration(duration * 1000)}</dd>
                 </React.Fragment>}
                 <dt>Expression</dt>
-                <dd><pre className="co-pre-wrap monitoring-query">{query}</pre></dd>
+                <dd>
+                  <Link to={queryBrowserURL(query)}>
+                    <pre className="co-pre-wrap monitoring-query">{query}</pre>
+                  </Link>
+                </dd>
               </dl>
             </div>
           </div>
@@ -380,12 +395,11 @@ const AlertRulesDetailsPage = withFallback(connect(ruleStateToProps)((props: Ale
       </div>
       <div className="co-m-pane__body">
         <div className="co-m-pane__body-group">
-          <SectionHeading text="Active Alerts">
-            <ToggleGraph />
-          </SectionHeading>
+          <ToggleGraph />
+          <SectionHeading text="Active Alerts" />
           <div className="row">
             <div className="col-sm-12">
-              <Graph numSamples={300} rule={rule} />
+              <Graph rule={rule} />
             </div>
           </div>
           <div className="row">
@@ -438,7 +452,7 @@ const SilencesDetailsPage = withFallback(connect(silenceParamToProps)((props: Si
     <StatusBox data={silence} label={SilenceResource.label} loaded={loaded} loadError={loadError}>
       <div className="co-m-nav-title co-m-nav-title--detail">
         <h1 className="co-m-pane__heading">
-          <div className="co-m-pane__name co-resource-item"><MonitoringResourceIcon className="co-m-resource-icon--lg" resource={SilenceResource} />{name}</div>
+          <div className="co-resource-item"><MonitoringResourceIcon className="co-m-resource-icon--lg" resource={SilenceResource} />{name}</div>
           <SilenceActionsMenu silence={silence} />
         </h1>
       </div>
@@ -494,34 +508,65 @@ const SilencesDetailsPage = withFallback(connect(silenceParamToProps)((props: Si
   </React.Fragment>;
 }));
 
-const AlertRow = ({obj}) => {
-  const {annotations = {}, labels = {}} = obj;
-  const state = alertState(obj);
+const tableAlertClasses = [
+  classNames('col-sm-7', 'col-xs-8'),
+  classNames('col-sm-3', 'col-xs-4'),
+  classNames('col-sm-2', 'hidden-xs'),
+  Kebab.columnClass,
+];
 
-  return <ResourceRow obj={obj}>
-    <div className="col-sm-7 col-xs-8">
-      <div className="co-resource-item">
-        <MonitoringResourceIcon resource={AlertResource} />
-        <Link to={alertURL(obj, obj.rule.id)} className="co-resource-item__resource-name">{labels.alertname}</Link>
-      </div>
-      <div className="monitoring-description">{annotations.description || annotations.message}</div>
-    </div>
-    <div className="col-sm-3 col-xs-4">
-      <AlertState state={state} />
-      <AlertStateDescription alert={obj} />
-    </div>
-    <div className="col-sm-2 hidden-xs co-truncate">{_.startCase(_.get(labels, 'severity')) || '-'}</div>
-    <div className="dropdown-kebab-pf">
-      <Kebab options={state === AlertStates.Firing || state === AlertStates.Pending ? [silenceAlert(obj), viewAlertRule(obj)] : [viewAlertRule(obj)]} />
-    </div>
-  </ResourceRow>;
+const AlertTableRow: React.FC<AlertTableRowProps> = ({obj, index, key, style}) => {
+  const {annotations = {}, labels} = obj;
+  const state = alertState(obj);
+  return (
+    <TableRow id={obj.rule.id} index={index} trKey={key} style={style}>
+      <TableData className={tableAlertClasses[0]}>
+        <div className="co-resource-item">
+          <MonitoringResourceIcon resource={AlertResource} />
+          <Link to={alertURL(obj, obj.rule.id)} data-test-id="alert-resource-link" className="co-resource-item__resource-name">{labels && labels.alertname}</Link>
+        </div>
+        <div className="monitoring-description">{annotations.description || annotations.message}</div>
+      </TableData>
+      <TableData className={tableAlertClasses[1]}>
+        <AlertState state={state} />
+        <AlertStateDescription alert={obj} />
+      </TableData>
+      <TableData className={classNames(tableAlertClasses[2], 'co-truncate')}>
+        {_.startCase(_.get(labels, 'severity')) || '-'}
+      </TableData>
+      <TableData className={tableAlertClasses[3]}>
+        <Kebab options={state === AlertStates.Firing || state === AlertStates.Pending ? [silenceAlert(obj), viewAlertRule(obj)] : [viewAlertRule(obj)]} />
+      </TableData>
+    </TableRow>
+  );
+};
+AlertTableRow.displayName = 'AlertTableRow';
+type AlertTableRowProps = {
+  obj: Alert;
+  index: number;
+  key?: string;
+  style: object;
 };
 
-const AlertHeader = props => <ListHeader>
-  <ColHead {...props} className="col-sm-7 col-xs-8" sortField="labels.alertname">Name</ColHead>
-  <ColHead {...props} className="col-sm-3 col-xs-4" sortFunc="alertStateOrder">State</ColHead>
-  <ColHead {...props} className="col-sm-2 hidden-xs" sortField="labels.severity">Severity</ColHead>
-</ListHeader>;
+const AlertTableHeader = () => [
+  {
+    title: 'Name', sortField: 'labels.alertname', transforms: [sortable],
+    props: { className: tableAlertClasses[0] },
+  },
+  {
+    title: 'State', sortFunc: 'alertStateOrder', transforms: [sortable],
+    props: { className: tableAlertClasses[1] },
+  },
+  {
+    title: 'Severity', sortField: 'labels.severity', transforms: [sortable],
+    props: { className: tableAlertClasses[2] },
+  },
+  {
+    title: '',
+    props: { className: tableAlertClasses[3] },
+  },
+];
+AlertTableHeader.displayName = 'AlertTableHeader';
 
 const AlertsPageDescription = () => <p className="co-help-text">
   Alerts help notify you when certain conditions in your environment are met. <ExternalLink href="https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/" text="Learn more about how alerts are configured." />
@@ -553,10 +598,8 @@ const filtersToProps = ({k8s}, {reduxID}) => {
 };
 
 const MonitoringListPage = connect(filtersToProps)(class InnerMonitoringListPage extends React.Component<ListPageProps> {
-  /* eslint-disable no-undef */
   props: ListPageProps;
   defaultNameFilter: string;
-  /* eslint-enable no-undef */
 
   constructor(props) {
     super(props);
@@ -588,24 +631,15 @@ const MonitoringListPage = connect(filtersToProps)(class InnerMonitoringListPage
 
     if (!params.get('sortBy')) {
       // Sort by rule name by default
-      store.dispatch(UIActions.sortList(reduxID, 'name', undefined, 'asc', 'Name'));
+      store.dispatch(UIActions.sortList(reduxID, 'name', undefined, false, 'asc', 'Name'));
     }
   }
 
   render() {
-    const {alertmanagerLinkPath, CreateButton, data, filters, Header, kindPlural, loaded, loadError, PageDescription, reduxID, Row, rowFilter} = this.props;
+    const {CreateButton, data, filters, Header, kindPlural, loaded, loadError, PageDescription, reduxID, Row, rowFilter} = this.props;
 
     return <React.Fragment>
-      <Helmet>
-        <title>{kindPlural}</title>
-      </Helmet>
       <div className="co-m-nav-title">
-        <h1 className="co-m-pane__heading">
-          <div className="co-m-pane__name co-resource-item">
-            {kindPlural}
-            <HeaderAlertmanagerLink path={alertmanagerLinkPath} />
-          </div>
-        </h1>
         <PageDescription />
       </div>
       <div className="co-m-pane__filter-bar">
@@ -617,19 +651,18 @@ const MonitoringListPage = connect(filtersToProps)(class InnerMonitoringListPage
         </div>
       </div>
       <div className="co-m-pane__body">
-        <div className="row">
-          <CheckBoxes
-            items={rowFilter.items}
-            itemCount={_.size(data)}
-            numbers={_.countBy(data, rowFilter.reducer)}
-            reduxIDs={[reduxID]}
-            selected={rowFilter.selected}
-            type={rowFilter.type}
-          />
-        </div>
+        <CheckBoxes
+          items={rowFilter.items}
+          itemCount={_.size(data)}
+          numbers={_.countBy(data, rowFilter.reducer)}
+          reduxIDs={[reduxID]}
+          selected={rowFilter.selected}
+          type={rowFilter.type}
+        />
         <div className="row">
           <div className="col-xs-12">
-            <List
+            <Table
+              aria-label={kindPlural}
               data={data}
               filters={filters}
               Header={Header}
@@ -637,6 +670,7 @@ const MonitoringListPage = connect(filtersToProps)(class InnerMonitoringListPage
               loadError={loadError}
               reduxID={reduxID}
               Row={Row}
+              virtualize
             />
           </div>
         </div>
@@ -647,21 +681,42 @@ const MonitoringListPage = connect(filtersToProps)(class InnerMonitoringListPage
 
 const AlertsPage_ = props => <MonitoringListPage
   {...props}
-  Header={AlertHeader}
+  Header={AlertTableHeader}
   kindPlural="Alerts"
   nameFilterID="alert-name"
   PageDescription={AlertsPageDescription}
   reduxID="monitoringRules"
-  Row={AlertRow}
+  Row={AlertTableRow}
   rowFilter={alertsRowFilter}
 />;
 const AlertsPage = withFallback(connect(alertsToProps)(AlertsPage_));
 
-const SilenceHeader = props => <ListHeader>
-  <ColHead {...props} className="col-sm-7 col-xs-8" sortField="name">Name</ColHead>
-  <ColHead {...props} className="col-sm-3 col-xs-4" sortFunc="silenceStateOrder">State</ColHead>
-  <ColHead {...props} className="col-sm-2 hidden-xs" sortField="firingAlerts.length">Firing Alerts</ColHead>
-</ListHeader>;
+const tableSilenceClasses = [
+  classNames('col-sm-7', 'col-xs-8'),
+  classNames('col-sm-3', 'col-xs-4'),
+  classNames('col-sm-2', 'hidden-xs'),
+  Kebab.columnClass,
+];
+
+const SilenceTableHeader = () => [
+  {
+    title: 'Name', sortField: 'name', transforms: [sortable],
+    props: { className: tableSilenceClasses[0] },
+  },
+  {
+    title: 'State', sortFunc: 'silenceStateOrder', transforms: [sortable],
+    props: { className: tableSilenceClasses[1] },
+  },
+  {
+    title: 'Firing Alerts', sortField: 'firingAlerts.length', transforms: [sortable],
+    props: { className: tableSilenceClasses[2] },
+  },
+  {
+    title: '',
+    props: { className: tableSilenceClasses[3] },
+  },
+];
+SilenceTableHeader.displayName = 'SilenceTableHeader';
 
 const SilenceRow = ({obj}) => {
   const state = silenceState(obj);
@@ -670,7 +725,7 @@ const SilenceRow = ({obj}) => {
     <div className="col-sm-7 col-xs-8">
       <div className="co-resource-item">
         <MonitoringResourceIcon resource={SilenceResource} />
-        <Link className="co-resource-item__resource-name" title={obj.id} to={`${SilenceResource.path}/${obj.id}`}>{obj.name}</Link>
+        <Link className="co-resource-item__resource-name" data-test-id="silence-resource-link" title={obj.id} to={`${SilenceResource.plural}/${obj.id}`}>{obj.name}</Link>
       </div>
       <div className="monitoring-label-list">
         <SilenceMatchersList silence={obj} />
@@ -689,6 +744,42 @@ const SilenceRow = ({obj}) => {
   </ResourceRow>;
 };
 
+const SilenceTableRow: React.FC<SilenceTableRowProps> = ({obj, index, key, style}) => {
+  const state = silenceState(obj);
+  return (
+    <TableRow id={obj.id} index={index} trKey={key} style={style}>
+      <TableData className={tableSilenceClasses[0]}>
+        <div className="co-resource-item">
+          <MonitoringResourceIcon resource={SilenceResource} />
+          <Link className="co-resource-item__resource-name" data-test-id="silence-resource-link" title={obj.id} to={`${SilenceResource.plural}/${obj.id}`}>{obj.name}</Link>
+        </div>
+        <div className="monitoring-label-list">
+          <SilenceMatchersList silence={obj} />
+        </div>
+      </TableData>
+      <TableData className={classNames(tableSilenceClasses[1], 'co-break-word')}>
+        <SilenceState silence={obj} />
+        {state === SilenceStates.Pending && <StateTimestamp text="Starts" timestamp={obj.startsAt} />}
+        {state === SilenceStates.Active && <StateTimestamp text="Ends" timestamp={obj.endsAt} />}
+        {state === SilenceStates.Expired && <StateTimestamp text="Expired" timestamp={obj.endsAt} />}
+      </TableData>
+      <TableData className={tableSilenceClasses[2]}>
+        {obj.firingAlerts.length}
+      </TableData>
+      <TableData className={tableSilenceClasses[3]}>
+        <SilenceKebab silence={obj} />
+      </TableData>
+    </TableRow>
+  );
+};
+SilenceTableRow.displayName = 'SilenceTableRow';
+export type SilenceTableRowProps = {
+  obj: Silence;
+  index: number;
+  key?: string;
+  style: object;
+};
+
 const SilencesPageDescription = () => <p className="co-help-text">
   Silences temporarily mute alerts based on a set of conditions that you define. Notifications are not sent for alerts that meet the given conditions.
 </p>;
@@ -705,19 +796,18 @@ const silencesRowFilter = {
 };
 
 const CreateButton = () => <Link className="co-m-primary-action" to="/monitoring/silences/~new">
-  <button className="btn btn-primary">Create Silence</button>
+  <Button variant="primary">Create Silence</Button>
 </Link>;
 
 const SilencesPage_ = props => <MonitoringListPage
   {...props}
-  alertmanagerLinkPath="/#/silences"
   CreateButton={CreateButton}
-  Header={SilenceHeader}
+  Header={SilenceTableHeader}
   kindPlural="Silences"
   nameFilterID="silence-name"
   PageDescription={SilencesPageDescription}
   reduxID="monitoringSilences"
-  Row={SilenceRow}
+  Row={SilenceTableRow}
   rowFilter={silencesRowFilter}
 />;
 const SilencesPage = withFallback(connect(silencesToProps)(SilencesPage_));
@@ -730,7 +820,7 @@ const toISODate = (dateStr: string): string => {
   return isNaN(timestamp) ? undefined : (new Date(timestamp)).toISOString();
 };
 
-const Text = props => <input {...props} type="text" className="form-control form-control--silence-text" />;
+const Text = props => <input {...props} type="text" className="pf-c-form-control" />;
 
 const Datetime = props => {
   const pattern = '\\d{4}/(0?[1-9]|1[012])/(0?[1-9]|[12]\\d|3[01]) (0?\\d|1\\d|2[0-3]):[0-5]\\d(:[0-5]\\d)?';
@@ -742,7 +832,7 @@ const Datetime = props => {
   </div>;
 };
 
-class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
+class SilenceForm_ extends React.Component<SilenceFormProps, SilenceFormState> {
   constructor(props) {
     super(props);
 
@@ -750,14 +840,12 @@ class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
     const startsAt = formatDate(now);
     const endsAt = formatDate(new Date(now.setHours(now.getHours() + 2)));
     const data = _.defaults(props.defaults, {startsAt, endsAt, matchers: [], createdBy: '', comment: ''});
-    this.state = {data, error: undefined, inProgress: false};
-
     if (_.isEmpty(data.matchers)) {
-      this.addMatcher();
+      data.matchers.push({name: '', value: '', isRegex: false});
     }
+    this.state = {data, error: undefined, inProgress: false};
   }
 
-  /* eslint-disable no-undef */
   setField = (path: string, v: any): void => {
     const data = Object.assign({}, this.state.data);
     _.set(data, path, v);
@@ -789,7 +877,7 @@ class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
   onSubmit = (e): void => {
     e.preventDefault();
 
-    const {alertManagerBaseURL} = (window as any).SERVER_FLAGS;
+    const {alertManagerBaseURL} = window.SERVER_FLAGS;
     if (!alertManagerBaseURL) {
       this.setState({error: 'Alertmanager URL not set'});
       return;
@@ -805,12 +893,11 @@ class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
       .then(({data}) => {
         this.setState({error: undefined});
         refreshPoller('silences');
-        history.push(`${SilenceResource.path}/${encodeURIComponent(_.get(data, 'silenceId'))}`);
+        history.push(`${SilenceResource.plural}/${encodeURIComponent(_.get(data, 'silenceId'))}`);
       })
       .catch(err => this.setState({error: _.get(err, 'json.error') || err.message || 'Error saving Silence'}))
       .then(() => this.setState({inProgress: false}));
   }
-  /* eslint-enable no-undef */
 
   render() {
     const {Info, saveButtonText, title} = this.props;
@@ -856,14 +943,14 @@ class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
               </label>
             </div>
             <div className="col-xs-1">
-              <button type="button" className="btn btn-link" onClick={() => this.removeMatcher(i)} aria-label="Remove matcher">
-                <i className="fa fa-minus-circle" aria-hidden="true" />
+              <button type="button" className="btn btn-link btn-link--inherit-color" onClick={() => this.removeMatcher(i)} aria-label="Remove matcher">
+                <MinusCircleIcon />
               </button>
             </div>
           </div>)}
-          <button type="button" className="btn btn-link btn--silence-add-more" onClick={this.addMatcher}>
-            <i className="fa fa-plus-circle" aria-hidden="true" /> Add More
-          </button>
+          <Button className="pf-m-link--align-left" onClick={this.addMatcher} type="button" variant="link">
+            <PlusCircleIcon className="co-icon-space-r" />Add More
+          </Button>
         </div>
         <div className="co-form-section__separator"></div>
 
@@ -873,12 +960,22 @@ class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
         </div>
         <div className="form-group">
           <label>Comment</label>
-          <textarea className="form-control" onChange={this.onFieldChange('comment')} value={data.comment} />
+          <textarea className="pf-c-form-control" onChange={this.onFieldChange('comment')} value={data.comment} />
         </div>
 
         <ButtonBar errorMessage={error} inProgress={inProgress}>
-          <button type="submit" className="btn btn-primary">{saveButtonText || 'Save'}</button>
-          <Link to={data.id ? `${SilenceResource.path}/${data.id}` : SilenceResource.path} className="btn btn-default">Cancel</Link>
+          <ActionGroup className="pf-c-form">
+            <Button
+              type="submit"
+              variant="primary">
+              {saveButtonText || 'Save'}
+            </Button>
+            <Button
+              onClick={history.goBack}
+              variant="secondary">
+              Cancel
+            </Button>
+          </ActionGroup>
         </ButtonBar>
       </form>
     </div>;
@@ -886,10 +983,7 @@ class SilenceForm_ extends SafetyFirst<SilenceFormProps, SilenceFormState> {
 }
 const SilenceForm = withFallback(SilenceForm_);
 
-const EditInfo = () => <div className="alert alert-info">
-  <span className="pficon pficon-info"></span>
-  When changes are saved, the currently existing silence will be expired and a new silence with the new configuration will take its place.
-</div>;
+const EditInfo = () => <Alert isInline className="co-alert" variant="info" title="Overwriting current silence">When changes are saved, the currently existing silence will be expired and a new silence with the new configuration will take its place.</Alert>;
 
 const EditSilence = connect(silenceParamToProps)(({loaded, loadError, silence}) => {
   const isExpired = silenceState(silence) === SilenceStates.Expired;
@@ -908,9 +1002,53 @@ const CreateSilence = () => {
     : <SilenceForm defaults={{matchers}} saveButtonText="Create" title="Silence Alert" />;
 };
 
-export class MonitoringUI extends React.Component<null, null> {
-  componentDidMount() {
-    const poll = (url: string, key: string, dataHandler: (data: any[]) => any): void => {
+const AlertManagerYAML = () => {
+  return <Firehose resources={[{kind: 'Secret', name: 'alertmanager-main', namespace: 'openshift-monitoring', isList: false, prop: 'obj'}]}>
+    <AlertManagerYAMLEditorWrapper />
+  </Firehose>;
+};
+
+const AlertingPage: React.SFC<AlertingPageProps> = ({match}) => {
+  const alertPath = '/monitoring/alerts';
+  const silencePath = '/monitoring/silences';
+  const YAMLPath = '/monitoring/alertmanageryaml';
+  return <React.Fragment>
+    <div className="co-m-nav-title co-m-nav-title--detail">
+      <h1 className="co-m-pane__heading">
+        <div className="co-m-pane__name co-resource-item">
+          <span className="co-resource-item__resource-name" data-test-id="resource-title">Alerting</span>
+          <HeaderAlertmanagerLink path="/#/alerts" />
+        </div>
+      </h1>
+    </div>
+    <div className="co-m-horizontal-nav__menu">
+      <ul className="co-m-horizontal-nav__menu-primary">
+        <li
+          className={classNames('co-m-horizontal-nav__menu-item', {'co-m-horizontal-nav-item--active': match.url === alertPath})}>
+          <Link to={alertPath}>Alerts</Link>
+        </li>
+        <li
+          className={classNames('co-m-horizontal-nav__menu-item', {'co-m-horizontal-nav-item--active': match.url === silencePath})}>
+          <Link to={silencePath}>Silences</Link>
+        </li>
+        <li
+          className={classNames('co-m-horizontal-nav__menu-item', {'co-m-horizontal-nav-item--active': match.url === YAMLPath})}>
+          <Link to={YAMLPath}>YAML</Link>
+        </li>
+        <li className="co-m-horizontal-nav__menu-item co-m-horizontal-nav__menu-item--divider"></li>
+      </ul>
+    </div>
+    <Switch>
+      <Route path="/monitoring/alerts" exact component={AlertsPage} />
+      <Route path="/monitoring/silences" exact component={SilencesPage} />
+      <Route path="/monitoring/alertmanageryaml" exact component={AlertManagerYAML} />
+    </Switch>
+  </React.Fragment>;
+};
+
+const PollerPages = () => {
+  React.useEffect(() => {
+    const poll = (url: string, key: 'alerts' | 'silences', dataHandler: (data: any[]) => any): void => {
       store.dispatch(UIActions.monitoringLoading(key));
       const poller = (): void => {
         coFetchJSON(url)
@@ -923,7 +1061,7 @@ export class MonitoringUI extends React.Component<null, null> {
       poller();
     };
 
-    const {alertManagerBaseURL, prometheusBaseURL} = (window as any).SERVER_FLAGS;
+    const {alertManagerBaseURL, prometheusBaseURL} = window.SERVER_FLAGS;
 
     if (prometheusBaseURL) {
       poll(`${prometheusBaseURL}/api/v1/rules`, 'alerts', data => {
@@ -965,27 +1103,26 @@ export class MonitoringUI extends React.Component<null, null> {
     } else {
       store.dispatch(UIActions.monitoringErrored('silences', new Error('alertManagerBaseURL not set')));
     }
-  }
 
-  componentWillUnmount() {
-    _.each(pollerTimeouts, t => clearTimeout(t));
-  }
+    return () => _.each(pollerTimeouts, clearTimeout);
+  }, []);
 
-  render() {
-    return <Switch>
-      <Redirect from="/monitoring" exact to="/monitoring/alerts" />
-      <Route path="/monitoring/alerts" exact component={AlertsPage} />
-      <Route path="/monitoring/alerts/:ruleID" exact component={AlertsDetailsPage} />
-      <Route path="/monitoring/alertrules/:id" exact component={AlertRulesDetailsPage} />
-      <Route path="/monitoring/silences" exact component={SilencesPage} />
-      <Route path="/monitoring/silences/~new" exact component={CreateSilence} />
-      <Route path="/monitoring/silences/:id" exact component={SilencesDetailsPage} />
-      <Route path="/monitoring/silences/:id/edit" exact component={EditSilence} />
-    </Switch>;
-  }
-}
+  return <Switch>
+    <Route path="/monitoring/(alertmanageryaml|alerts|silences)" exact component={AlertingPage} />
+    <Route path="/monitoring/alertrules/:id" exact component={AlertRulesDetailsPage} />
+    <Route path="/monitoring/alerts/:ruleID" exact component={AlertsDetailsPage} />
+    <Route path="/monitoring/silences/:id" exact component={SilencesDetailsPage} />
+    <Route path="/monitoring/silences/:id/edit" exact component={EditSilence} />
+  </Switch>;
+};
+
+export const MonitoringUI = () => <Switch>
+  <Redirect from="/monitoring" exact to="/monitoring/alerts" />
+  <Route path="/monitoring/query-browser" exact component={QueryBrowserPage} />
+  <Route path="/monitoring/silences/~new" exact component={CreateSilence} />
+  <Route component={PollerPages} />
+</Switch>;
 
-/* eslint-disable no-undef, no-unused-vars */
 type Silence = {
   comment: string;
   createdBy: string;
@@ -1004,7 +1141,7 @@ type Silences = {
   loaded: boolean;
   loadError?: string;
 };
-type Alert = {
+export type Alert = {
   activeAt?: string;
   annotations: any;
   labels: {
@@ -1015,13 +1152,14 @@ type Alert = {
   silencedBy?: Silence[];
   state: AlertStates;
   value?: number;
+  fingerprint?: string;
 };
 type Rule = {
   alerts: Alert[];
   annotations: any;
   duration: number;
   id: string;
-  labels: {[key: string]: string};
+  labels: Labels;
   name: string;
   query: string;
 };
@@ -1053,7 +1191,7 @@ export type SilencesDetailsPageProps = {
 };
 export type SilenceFormProps = {
   defaults?: any;
-  Info: React.ComponentType<any>;
+  Info: React.ComponentType<{}>;
   saveButtonText?: string;
   title: string;
   urls: {key: string}[];
@@ -1065,18 +1203,22 @@ export type SilenceFormState = {
 };
 export type ListPageProps = {
   alertmanagerLinkPath: string;
-  CreateButton: React.ComponentType<any>;
+  CreateButton: React.ComponentType<{}>;
   data: Rule[] | Silence[];
   filters: {[key: string]: any};
-  Header: React.ComponentType<any>;
+  Header: (...args) => any[];
   itemCount: number;
   kindPlural: string;
   loaded: boolean;
   loadError?: string;
   match: {path: string};
   nameFilterID: string;
-  PageDescription: React.ComponentType<any>;
+  PageDescription: React.ComponentType<{}>;
   reduxID: string;
   Row: React.ComponentType<any>;
   rowFilter: {type: string, selected: string[], reducer: (any) => string, items: {id: string, title: string}[]};
 };
+
+type AlertingPageProps = {
+  match: any;
+};
