@@ -1,15 +1,16 @@
-/* eslint-disable no-unused-vars */
-
 import * as _ from 'lodash-es';
 import * as React from 'react';
+import * as classNames from 'classnames';
+import { sortable } from '@patternfly/react-table';
 
-import { nodeStatus, makeNodeSchedulable, K8sResourceKind, referenceForModel } from '../module/k8s';
+import { Status } from '@console/shared';
+import { getNodeRoles, nodeStatus, makeNodeSchedulable, NodeKind, referenceForModel } from '../module/k8s';
 import { ResourceEventStream } from './events';
-import { ColHead, DetailsPage, List, ListHeader, ListPage, ResourceRow } from './factory';
+import { Table, TableRow, TableData, DetailsPage, ListPage } from './factory';
 import { configureUnschedulableModal } from './modals';
 import { PodsPage } from './pod';
-import { Kebab, navFactory, LabelList, ResourceKebab, SectionHeading, ResourceLink, Timestamp, units, cloudProviderNames, cloudProviderID, pluralize, StatusIcon } from './utils';
-import { Line, requirePrometheus } from './graphs';
+import { Kebab, navFactory, LabelList, ResourceKebab, SectionHeading, ResourceLink, Timestamp, units, cloudProviderNames, cloudProviderID, pluralize, humanizeDecimalBytes, humanizeCpuCores, useAccessReview, humanizeDecimalBytesPerSec } from './utils';
+import { Area, requirePrometheus } from './graphs';
 import { MachineModel, NodeModel } from '../models';
 import { CamelCaseWrap } from './utils/camel-case-wrap';
 
@@ -17,12 +18,26 @@ const MarkAsUnschedulable = (kind, obj) => ({
   label: 'Mark as Unschedulable',
   hidden: _.get(obj, 'spec.unschedulable'),
   callback: () => configureUnschedulableModal({resource: obj}),
+  accessReview: {
+    group: kind.apiGroup,
+    resource: kind.plural,
+    name: obj.metadata.name,
+    namespace: obj.metadata.namespace,
+    verb: 'patch',
+  },
 });
 
 const MarkAsSchedulable = (kind, obj) => ({
   label: 'Mark as Schedulable',
   hidden: !_.get(obj, 'spec.unschedulable', false),
   callback: () => makeNodeSchedulable(obj),
+  accessReview: {
+    group: kind.apiGroup,
+    resource: kind.plural,
+    name: obj.metadata.name,
+    namespace: obj.metadata.namespace,
+    verb: 'patch',
+  },
 });
 
 const { ModifyLabels, ModifyAnnotations, Edit } = Kebab.factory;
@@ -30,7 +45,7 @@ const menuActions = [MarkAsSchedulable, MarkAsUnschedulable, ModifyLabels, Modif
 
 const NodeKebab = ({node}) => <ResourceKebab actions={menuActions} kind="Node" resource={node} />;
 
-const getMachine = (node: K8sResourceKind) => {
+const getMachine = (node: NodeKind) => {
   const machine = _.get(node, 'metadata.annotations["machine.openshift.io/machine"]');
   if (!machine) {
     return null;
@@ -49,42 +64,78 @@ export const NodeIPList = ({ips, expand = false}) => <div>
   </div>)}
 </div>;
 
-const Header = props => {
-  if (!props.data) {
-    return null;
-  }
-  return <ListHeader>
-    <ColHead {...props} className="col-md-4 col-sm-5 col-xs-8" sortField="metadata.name">Node Name</ColHead>
-    <ColHead {...props} className="col-md-2 col-sm-3 col-xs-4" sortFunc="nodeReadiness">Status</ColHead>
-    <ColHead {...props} className="col-md-3 col-sm-4 hidden-xs" sortField="metadata.annotations['machine.openshift.io/machine']">Machine</ColHead>
-    <ColHead {...props} className="col-md-3 hidden-sm hidden-xs" sortField="status.addresses">Node Addresses</ColHead>
-  </ListHeader>;
+const tableColumnClasses = [
+  classNames('col-md-5', 'col-sm-5', 'col-xs-8'),
+  classNames('col-md-2', 'col-sm-3', 'col-xs-4'),
+  classNames('col-md-2', 'col-sm-4', 'hidden-xs'),
+  classNames('col-md-3', 'hidden-sm', 'hidden-xs'),
+  Kebab.columnClass,
+];
+
+const NodeTableHeader = () => {
+  return [
+    {
+      title: 'Name', sortField: 'metadata.name', transforms: [sortable],
+      props: { className: tableColumnClasses[0] },
+    },
+    {
+      title: 'Status', sortFunc: 'nodeReadiness', transforms: [sortable],
+      props: { className: tableColumnClasses[1] },
+    },
+    {
+      title: 'Role', sortFunc: 'nodeRoles', transforms: [sortable],
+      props: { className: tableColumnClasses[2] },
+    },
+    {
+      title: 'Machine', sortField: 'metadata.annotations[\'machine.openshift.io/machine\']', transforms: [sortable],
+      props: { className: tableColumnClasses[3] },
+    },
+    {
+      title: '', props: { className: tableColumnClasses[4] },
+    },
+  ];
 };
+NodeTableHeader.displayName = 'NodeTableHeader';
 
-const NodeStatus = ({node}) => <StatusIcon status={nodeStatus(node)} />;
+const NodeStatus: React.FC<{node: NodeKind}> = ({node}) => (
+  <>
+    <Status status={nodeStatus(node)} />
+    {node.spec.unschedulable && <small className="text-muted">Scheduling Disabled</small>}
+  </>
+);
 
-const NodeRow = ({obj: node, expand}) => {
+const NodeTableRow: React.FC<NodeTableRowProps> = ({obj: node, index, key, style}) => {
   const machine = getMachine(node);
-
-  return <ResourceRow obj={node}>
-    <div className="col-md-4 col-sm-5 col-xs-8">
-      <ResourceLink kind="Node" name={node.metadata.name} title={node.metadata.uid} />
-    </div>
-    <div className="col-md-2 col-sm-3 col-xs-4"><NodeStatus node={node} /></div>
-    <div className="col-md-3 col-sm-4 hidden-xs">
-      {machine && <ResourceLink kind={referenceForModel(MachineModel)} name={machine.name} namespace={machine.namespace} />}
-    </div>
-    <div className="col-md-3 hidden-sm hidden-xs"><NodeIPList ips={node.status.addresses} expand={expand} /></div>
-    {expand && <div className="col-xs-12">
-      <LabelList kind="Node" labels={node.metadata.labels} />
-    </div>}
-    <div className="dropdown-kebab-pf">
-      <NodeKebab node={node} />
-    </div>
-  </ResourceRow>;
+  const roles = getNodeRoles(node).sort();
+  return (
+    <TableRow id={node.metadata.uid} index={index} trKey={key} style={style}>
+      <TableData className={tableColumnClasses[0]}>
+        <ResourceLink kind="Node" name={node.metadata.name} title={node.metadata.uid} />
+      </TableData>
+      <TableData className={tableColumnClasses[1]}>
+        <NodeStatus node={node} />
+      </TableData>
+      <TableData className={tableColumnClasses[2]}>
+        {roles.length ? roles.join(', ') : '-'}
+      </TableData>
+      <TableData className={tableColumnClasses[3]}>
+        {machine && <ResourceLink kind={referenceForModel(MachineModel)} name={machine.name} namespace={machine.namespace} />}
+      </TableData>
+      <TableData className={tableColumnClasses[4]}>
+        <NodeKebab node={node} />
+      </TableData>
+    </TableRow>
+  );
+};
+NodeTableRow.displayName = 'NodeTableRow';
+type NodeTableRowProps = {
+  obj: NodeKind;
+  index: number;
+  key?: string;
+  style: object;
 };
 
-const NodesList = props => <List {...props} Header={Header} Row={NodeRow} />;
+const NodesList = props => <Table {...props} aria-label="Nodes" Header={NodeTableHeader} Row={NodeTableRow} virtualize />;
 
 const filters = [{
   type: 'node-status',
@@ -95,41 +146,72 @@ const filters = [{
     {id: 'Not Ready', title: 'Not Ready'},
   ],
 }];
-export const NodesPage = props => <ListPage {...props} ListComponent={NodesList} rowFilters={filters} canExpand={true} />;
+export const NodesPage = props => <ListPage {...props} ListComponent={NodesList} rowFilters={filters} />;
 
 const NodeGraphs = requirePrometheus(({node}) => {
+  const instanceQuery = `{instance='${node.metadata.name}'}`;
   const nodeIp = _.find<{type: string, address: string}>(node.status.addresses, {type: 'InternalIP'});
   const ipQuery = nodeIp && `{instance=~'${nodeIp.address}:.*'}`;
 
   return <React.Fragment>
     <div className="row">
-      <div className="col-md-4">
-        <Line title="Memory Usage" query={ipQuery && `node_memory_Active_bytes${ipQuery}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Memory Usage"
+          humanize={humanizeDecimalBytes}
+          query={`node_memory_Active_bytes${instanceQuery}`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="CPU Usage" query={ipQuery && `instance:node_cpu:rate:sum${ipQuery}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="CPU Usage"
+          humanize={humanizeCpuCores}
+          query={`instance:node_cpu:rate:sum${instanceQuery}`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="Number of Pods" query={ipQuery && `kubelet_running_pod_count${ipQuery}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Number of Pods"
+          query={ipQuery && `kubelet_running_pod_count${ipQuery}`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="Network In" query={ipQuery && `instance:node_network_receive_bytes:rate:sum${ipQuery}`} />
+    </div>
+    <div className="row">
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Network In"
+          humanize={humanizeDecimalBytesPerSec}
+          query={`instance:node_network_receive_bytes:rate:sum${instanceQuery}`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="Network Out" query={ipQuery && `instance:node_network_transmit_bytes:rate:sum${ipQuery}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Network Out"
+          humanize={humanizeDecimalBytesPerSec}
+          query={`instance:node_network_transmit_bytes:rate:sum${instanceQuery}`}
+        />
       </div>
-      <div className="col-md-4">
-        <Line title="Filesystem" query={ipQuery && `instance:node_filesystem_usage:sum${ipQuery}`} />
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Filesystem"
+          humanize={humanizeDecimalBytes}
+          query={`instance:node_filesystem_usage:sum${instanceQuery}`}
+        />
       </div>
     </div>
-
-    <br />
   </React.Fragment>;
 });
 
 const Details = ({obj: node}) => {
   const images = _.filter(node.status.images, 'names');
   const machine = getMachine(node);
+  const canUpdate = useAccessReview({
+    group: NodeModel.apiGroup,
+    resource: NodeModel.plural,
+    verb: 'patch',
+    name: node.metadata.name,
+    namespace: node.metadata.namespace,
+  });
   return <React.Fragment>
     <div className="co-m-pane__body">
       <SectionHeading text="Node Overview" />
@@ -139,6 +221,8 @@ const Details = ({obj: node}) => {
           <dl className="co-m-pane__details">
             <dt>Node Name</dt>
             <dd>{node.metadata.name || '-'}</dd>
+            <dt>Status</dt>
+            <dd><NodeStatus node={node} /></dd>
             <dt>External ID</dt>
             <dd>{_.get(node, 'spec.externalID', '-')}</dd>
             <dt>Node Addresses</dt>
@@ -146,9 +230,17 @@ const Details = ({obj: node}) => {
             <dt>Node Labels</dt>
             <dd><LabelList kind="Node" labels={node.metadata.labels} /></dd>
             <dt>Taints</dt>
-            <dd><button type="button" className="btn btn-link co-modal-btn-link co-modal-btn-link--left" onClick={Kebab.factory.ModifyTaints(NodeModel, node).callback}>{pluralize(_.size(node.spec.taints), 'Taint')}</button></dd>
+            <dd>
+              {canUpdate
+                ? <button type="button" className="btn btn-link co-modal-btn-link co-modal-btn-link--left" onClick={Kebab.factory.ModifyTaints(NodeModel, node).callback}>{pluralize(_.size(node.spec.taints), 'Taint')}</button>
+                : pluralize(_.size(node.spec.taints), 'Taint')}
+            </dd>
             <dt>Annotations</dt>
-            <dd><button type="button" className="btn btn-link co-modal-btn-link co-modal-btn-link--left" onClick={Kebab.factory.ModifyAnnotations(NodeModel, node).callback}>{pluralize(_.size(node.metadata.annotations), 'Annotation')}</button></dd>
+            <dd>
+              {canUpdate
+                ? <button type="button" className="btn btn-link co-modal-btn-link co-modal-btn-link--left" onClick={Kebab.factory.ModifyAnnotations(NodeModel, node).callback}>{pluralize(_.size(node.metadata.annotations), 'Annotation')}</button>
+                : pluralize(_.size(node.metadata.annotations), 'Annotation')}
+            </dd>
             {machine && <React.Fragment>
               <dt>Machine</dt>
               <dd><ResourceLink kind={referenceForModel(MachineModel)} name={machine.name} namespace={machine.namespace} /></dd>
@@ -227,8 +319,8 @@ const Details = ({obj: node}) => {
           </thead>
           <tbody>
             {_.map(images, (image, i) => <tr key={i}>
-              <td className="co-break-all">{image.names.find(name => !name.includes('@')) || image.names[0]}</td>
-              <td>{units.humanize(image.sizeBytes, 'decimalBytes', true).string || '-'}</td>
+              <td className="co-break-all co-select-to-copy">{image.names.find((name: string) => !name.includes('@') && !name.includes('<none>')) || image.names[0]}</td>
+              <td>{units.humanize(image.sizeBytes, 'binaryBytes', true).string || '-'}</td>
             </tr>)}
           </tbody>
         </table>
