@@ -1,55 +1,49 @@
-/* eslint-disable no-unused-vars, no-undef */
 import * as _ from 'lodash-es';
 import * as classnames from 'classnames';
 import * as fuzzy from 'fuzzysearch';
 import * as React from 'react';
 import { connect } from 'react-redux';
 import { CSSTransition } from 'react-transition-group';
-import { Helmet } from 'react-helmet';
 import { Link } from 'react-router-dom';
-import { Toolbar, EmptyState } from 'patternfly-react';
 
 import { coFetchJSON } from '../../co-fetch';
 import { getBuildNumber } from '../../module/k8s/builds';
-import { prometheusTenancyBasePath } from '../graphs';
+import { PROMETHEUS_TENANCY_BASE_PATH } from '../graphs';
 import { TextFilter } from '../factory';
 import { PodStatus } from '../pod';
-import { UIActions, formatNamespacedRouteForResource } from '../../ui/ui-actions';
+import * as UIActions from '../../actions/ui';
 import {
   apiVersionForModel,
   K8sResourceKind,
   LabelSelector,
+  PodKind,
+  PodTemplate,
 } from '../../module/k8s';
-import {
-  withStartGuide,
-  WithStartGuideProps,
-} from '../start-guide';
 import {
   DaemonSetModel,
   DeploymentModel,
   DeploymentConfigModel,
   PodModel,
-  ProjectModel,
   ReplicationControllerModel,
   ReplicaSetModel,
   StatefulSetModel,
 } from '../../models';
 import {
-  ActionsMenu,
   CloseButton,
-  KebabAction,
   Dropdown,
   Firehose,
   StatusBox,
-  EmptyBox,
   resourceObjPath,
+  FirehoseResult,
+  FirehoseResource,
+  MsgBox,
 } from '../utils';
 
-import { overviewMenuActions, OverviewNamespaceDashboard } from './namespace-overview';
 import { ProjectOverview } from './project-overview';
 import { ResourceOverviewPage } from './resource-overview-page';
-import { OverviewViewOption, OverviewSpecialGroup } from './constants';
-
+import { OverviewSpecialGroup } from './constants';
+import * as plugins from '../../plugins';
+import { OverviewCRD } from '@console/plugin-sdk';
 
 // List of container status waiting reason values that we should call out as errors in project status rows.
 const CONTAINER_WAITING_STATE_ERROR_REASONS = ['CrashLoopBackOff', 'ErrImagePull', 'ImagePullBackOff'];
@@ -70,9 +64,6 @@ const DEFAULT_GROUP_NAME = 'other resources';
 // Interval at which metrics are retrieved and updated
 const METRICS_POLL_INTERVAL = 30 * 1000;
 
-// Namespace prefixes that are reserved and should not have calls to action on empty state
-const RESERVED_NS_PREFIXES = ['openshift-', 'kube-', 'kubernetes-'];
-
 // Annotation key for image triggers
 const TRIGGERS_ANNOTATION = 'image.openshift.io/triggers';
 
@@ -194,6 +185,42 @@ const combinePodAlerts = (pods: K8sResourceKind[]): OverviewItemAlerts => _.redu
   ...getPodAlerts(pod),
 }), {});
 
+
+const getBuildAlerts = (buildConfigs: BuildConfigOverviewItem[]): OverviewItemAlerts => {
+  const buildAlerts = {};
+  const addAlert = (build: K8sResourceKind, buildPhase: string) => _.set(buildAlerts, `${build.metadata.uid}--build${buildPhase}`, {severity: `build${buildPhase}`, message: _.get(build, ['status', 'message'], buildPhase)});
+
+  _.each(buildConfigs, bc => {
+    let seenComplete = false;
+    // Requires builds to be sorted by most recent first.
+    _.each(bc.builds, (build: K8sResourceKind) => {
+      const buildPhase = _.get(build, ['status', 'phase']);
+      switch (buildPhase) {
+        case 'Complete':
+          seenComplete = true;
+          break;
+        case 'Failed':
+        case 'Error':
+          if (!seenComplete) {
+            // show failure/error
+            addAlert(build, buildPhase);
+          }
+          break;
+        case 'New':
+        case 'Pending':
+        case 'Running':
+          // show new/pending/running
+          addAlert(build, buildPhase);
+          break;
+        default:
+          break;
+      }
+    });
+  });
+
+  return buildAlerts;
+};
+
 const getReplicationControllerAlerts = (rc: K8sResourceKind): OverviewItemAlerts => {
   const phase = getDeploymentPhase(rc);
   const version = getDeploymentConfigVersion(rc);
@@ -219,7 +246,7 @@ const getReplicationControllerAlerts = (rc: K8sResourceKind): OverviewItemAlerts
   }
 };
 
-const getResourcePausedAlert = (resource): OverviewItemAlerts => {
+const getResourcePausedAlert = (resource: K8sResourceKind): OverviewItemAlerts => {
   if (!resource.spec.paused) {
     return {};
   }
@@ -231,7 +258,7 @@ const getResourcePausedAlert = (resource): OverviewItemAlerts => {
   };
 };
 
-const getOwnedResources = ({metadata:{uid}}: K8sResourceKind, resources: K8sResourceKind[]): K8sResourceKind[] => {
+const getOwnedResources = <T extends K8sResourceKind>({metadata:{uid}}: K8sResourceKind, resources: T[]): T[] => {
   return _.filter(resources, ({metadata:{ownerReferences}}) => {
     return _.some(ownerReferences, {
       uid,
@@ -279,7 +306,7 @@ const sortReplicationControllersByRevision = (replicationControllers: K8sResourc
   return sortByRevision(replicationControllers, getDeploymentConfigVersion);
 };
 
-const sortBuilds = (builds: K8sResourceKind[]): K8sResourceKind[] => {
+export const sortBuilds = (builds: K8sResourceKind[]): K8sResourceKind[] => {
 
   const byCreationTime = (left, right) => {
     const leftCreationTime = new Date(_.get(left, 'metadata.creationTimestamp', Date.now()));
@@ -299,8 +326,6 @@ const sortBuilds = (builds: K8sResourceKind[]): K8sResourceKind[] => {
   return builds.sort(byBuildNumber);
 };
 
-const isReservedNamespace = (ns: string) => ns === 'default' || ns === 'openshift' || RESERVED_NS_PREFIXES.some(prefix => _.startsWith(ns, prefix));
-
 const OverviewItemReadiness: React.SFC<OverviewItemReadinessProps> = ({desired = 0, ready = 0, resource}) => {
   const href = `${resourceObjPath(resource, resource.kind)}/pods`;
   return <Link to={href}>
@@ -308,47 +333,13 @@ const OverviewItemReadiness: React.SFC<OverviewItemReadinessProps> = ({desired =
   </Link>;
 };
 
-const overviewEmptyStateToProps = ({UI}) => ({
-  activeNamespace: UI.get('activeNamespace'),
-  resources: UI.getIn(['overview', 'resources']),
-});
-
-const OverviewEmptyState = connect(overviewEmptyStateToProps)(({activeNamespace, resources}) => {
-  // Don't encourage users to add content to system namespaces.
-  if (resources.isEmpty() && !isReservedNamespace(activeNamespace)) {
-    return <EmptyState>
-      <EmptyState.Title>
-        Get started with your project.
-      </EmptyState.Title>
-      <EmptyState.Info>
-        Add content to your project from the catalog of web frameworks, databases, and other components. You may also deploy an existing image or create resources using YAML definitions.
-      </EmptyState.Info>
-      <EmptyState.Action>
-        <Link to="/catalog" className="btn btn-primary">
-          Browse Catalog
-        </Link>
-      </EmptyState.Action>
-      <EmptyState.Action secondary>
-        <Link className="btn btn-default" to={`/deploy-image?preselected-ns=${activeNamespace}`}>
-          Deploy Image
-        </Link>
-        <Link className="btn btn-default" to={formatNamespacedRouteForResource('import', activeNamespace)}>
-          Import YAML
-        </Link>
-      </EmptyState.Action>
-    </EmptyState>;
-  }
-  return <EmptyBox label="Resources" />;
-});
-
 const headingStateToProps = ({UI}): OverviewHeadingPropsFromState => {
-  const {selectedView, selectedGroup, groupOptions, filterValue} = UI.get('overview').toJS();
-  return {groupOptions, selectedGroup, selectedView, filterValue};
+  const {selectedGroup, labels, filterValue} = UI.get('overview').toJS();
+  return {labels, selectedGroup, filterValue};
 };
 
 const headingDispatchToProps = (dispatch): OverviewHeadingPropsFromDispatch => ({
-  selectView: (view: OverviewViewOption) => dispatch(UIActions.selectOverviewView(view)),
-  selectGroup: (group: string) => dispatch(UIActions.updateOverviewSelectedGroup(group)),
+  selectGroup: (group: OverviewSpecialGroup) => dispatch(UIActions.updateOverviewSelectedGroup(group)),
   changeFilter: (value: string) => dispatch(UIActions.updateOverviewFilterValue(value)),
 });
 
@@ -359,71 +350,34 @@ class OverviewHeading_ extends React.Component<OverviewHeadingProps> {
   }
 
   render() {
-    const {changeFilter, disabled, filterValue, firstLabel = '', groupOptions, selectGroup, selectedGroup, selectView, selectedView, title, project} = this.props;
-    return <div className={classnames('co-m-nav-title co-m-nav-title--overview', { 'overview-filter-group': selectedView === OverviewViewOption.RESOURCES })}>
-      {
-        title &&
-        <h1 className="co-m-pane__heading co-m-pane__heading--overview">
-          <div className="co-m-pane__name co-m-pane__name--overview">{title}</div>
-        </h1>
-      }
-      {!_.isEmpty(project) && <div className={classnames('overview-view-selector', {'selected-view__resources': selectedView === OverviewViewOption.RESOURCES })}>
-        <div className="form-group btn-group">
-          <button
-            type="button"
-            className={classnames('btn btn-default', { 'btn-primary': selectedView === OverviewViewOption.RESOURCES })}
-            aria-label="Resources"
-            title="Resources"
-            disabled={disabled}
-            onClick={() => selectView(OverviewViewOption.RESOURCES)}
-          >
-            <i className="fa fa-list-ul" aria-hidden="true" />
-            Resources
-          </button>
-          <button
-            type="button"
-            className={classnames('btn btn-default', { 'btn-primary': selectedView === OverviewViewOption.DASHBOARD })}
-            aria-label="Dashboard"
-            title="Dashboard"
-            disabled={disabled}
-            onClick={() => selectView(OverviewViewOption.DASHBOARD)}
-          >
-            <i className="fa fa-dashboard" aria-hidden="true" />
-            Dashboard
-          </button>
-        </div>
-        <Toolbar className="overview-toolbar" preventSubmit>
-          <Toolbar.RightContent>
-            {selectedView === OverviewViewOption.RESOURCES && <React.Fragment>
-              <div className="form-group overview-toolbar__form-group">
-                <Dropdown
-                  className="overview-toolbar__dropdown"
-                  menuClassName="dropdown-menu--text-wrap"
-                  items={groupOptions}
-                  onChange={selectGroup}
-                  titlePrefix="Group by"
-                  title={groupOptions[selectedGroup] || 'Select Category'}
-                  spacerBefore={new Set([firstLabel])}
-                  headerBefore={{[firstLabel]: 'Label'}}
-                />
-              </div>
-              <div className="form-group overview-toolbar__form-group">
-                <div className="overview-toolbar__text-filter">
-                  <TextFilter
-                    autoFocus={!disabled}
-                    defaultValue={filterValue}
-                    label="by name"
-                    onChange={(e) => changeFilter(e.target.value)}
-                  />
-                </div>
-              </div>
-            </React.Fragment>}
-            {selectedView === OverviewViewOption.DASHBOARD && !_.isEmpty(project) && <div className="form-group">
-              <ActionsMenu actions={overviewMenuActions.map((a: KebabAction) => a(ProjectModel, project))} />
-            </div>}
-          </Toolbar.RightContent>
-        </Toolbar>
-      </div>}
+    const {changeFilter, filterValue, labels, selectGroup, selectedGroup} = this.props;
+    const firstLabel = _.first(labels) || '';
+    const dropdownItems = {
+      [OverviewSpecialGroup.GROUP_BY_APPLICATION]: 'Application',
+      [OverviewSpecialGroup.GROUP_BY_RESOURCE]: 'Resource',
+      ..._.zipObject(labels, labels),
+    };
+
+    return <div className="co-m-pane__filter-bar">
+      <div className="co-m-pane__filter-bar-group">
+        <Dropdown
+          className="btn-group"
+          menuClassName="dropdown-menu--text-wrap"
+          items={dropdownItems}
+          onChange={selectGroup}
+          titlePrefix="Group by"
+          title={dropdownItems[selectedGroup] || 'Select Category'}
+          spacerBefore={new Set([firstLabel])}
+          headerBefore={{[firstLabel]: 'Label'}}
+        />
+      </div>
+      <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
+        <TextFilter
+          defaultValue={filterValue}
+          label="by name"
+          onChange={(e) => changeFilter(e.target.value)}
+        />
+      </div>
     </div>;
   }
 }
@@ -431,15 +385,15 @@ class OverviewHeading_ extends React.Component<OverviewHeadingProps> {
 const OverviewHeading = connect<OverviewHeadingPropsFromState, OverviewHeadingPropsFromDispatch, OverviewHeadingOwnProps>(headingStateToProps, headingDispatchToProps)(OverviewHeading_);
 
 const mainContentStateToProps = ({UI}): OverviewMainContentPropsFromState => {
-  const {filterValue, metrics, selectedView, selectedGroup, groupOptions} = UI.get('overview').toJS();
-  return {filterValue, groupOptions, metrics, selectedGroup, selectedView};
+  const {filterValue, metrics, selectedGroup, labels} = UI.get('overview').toJS();
+  return {filterValue, labels, metrics, selectedGroup};
 };
 
 const mainContentDispatchToProps = (dispatch): OverviewMainContentPropsFromDispatch => ({
-  updateGroupOptions: (groups: { [key: string]: string }) => dispatch(UIActions.updateOverviewGroupOptions(groups)),
+  updateLabels: (labels: string[]) => dispatch(UIActions.updateOverviewLabels(labels)),
   updateMetrics: (metrics: OverviewMetrics) => dispatch(UIActions.updateOverviewMetrics(metrics)),
   updateResources: (items: OverviewItem[]) => dispatch(UIActions.updateOverviewResources(items)),
-  updateSelectedGroup: (group: string) => dispatch(UIActions.updateOverviewSelectedGroup(group)),
+  updateSelectedGroup: (group: OverviewSpecialGroup) => dispatch(UIActions.updateOverviewSelectedGroup(group)),
 });
 
 class OverviewMainContent_ extends React.Component<OverviewMainContentProps, OverviewMainContentState> {
@@ -449,8 +403,8 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     items: [],
     filteredItems: [],
     groupedItems: [],
-    firstLabel: '',
-  };
+    ...this.createOverviewData(),
+  }
 
   componentDidMount(): void {
     this.fetchMetrics();
@@ -460,7 +414,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     clearInterval(this.metricsInterval);
   }
 
-  componentDidUpdate(prevProps: OverviewMainContentProps, prevState: OverviewMainContentState): void {
+  componentDidUpdate(prevProps: OverviewMainContentProps): void {
     const {
       builds,
       buildConfigs,
@@ -492,7 +446,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       || !_.isEqual(routes, prevProps.routes)
       || !_.isEqual(services, prevProps.services)
       || !_.isEqual(statefulSets, prevProps.statefulSets)) {
-      this.createOverviewData();
+      this.setState(this.createOverviewData());
     } else if (filterValue !== prevProps.filterValue) {
       const filteredItems = this.filterItems(this.state.items);
       this.setState({
@@ -504,7 +458,6 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
         groupedItems: groupItems(this.state.filteredItems, selectedGroup),
       });
     }
-
     // Fetch new metrics when the namespace changes.
     if (namespace !== prevProps.namespace) {
       clearInterval(this.metricsInterval);
@@ -513,21 +466,21 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
   }
 
   fetchMetrics = (): void => {
-    if (!prometheusTenancyBasePath) {
+    if (!PROMETHEUS_TENANCY_BASE_PATH) {
       return;
     }
 
     const { metrics: previousMetrics, namespace } = this.props;
     const queries = {
-      memory: `pod_name:container_memory_usage_bytes:sum{namespace="${namespace}"}`,
+      memory: `sum(container_memory_working_set_bytes{namespace='${namespace}',container='',pod!=''}) BY (pod, namespace)`,
       cpu: `pod_name:container_cpu_usage:sum{namespace="${namespace}"}`,
     };
 
     const promises = _.map(queries, (query, name) => {
-      const url = `${prometheusTenancyBasePath}/api/v1/query?namespace=${namespace}&query=${encodeURIComponent(query)}`;
+      const url = `${PROMETHEUS_TENANCY_BASE_PATH}/api/v1/query?namespace=${namespace}&query=${encodeURIComponent(query)}`;
       return coFetchJSON(url).then(({ data: {result} }) => {
         const byPod: MetricValuesByPod = result.reduce((acc, { metric, value }) => {
-          acc[metric.pod_name] = Number(value[1]);
+          acc[metric.pod || metric.pod_name] = Number(value[1]);
           return acc;
         }, {});
         return { [name]: byPod };
@@ -564,26 +517,16 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     });
   }
 
-  getGroupOptionsFromLabels(items: OverviewItem[]): any {
-    const specialGroups = {
-      [OverviewSpecialGroup.GROUP_BY_APPLICATION]: 'Application',
-      [OverviewSpecialGroup.GROUP_BY_RESOURCE]: 'Resource',
-    };
-
-    const labelKeys = _.flatMap(items, item => _.keys(_.get(item, 'obj.metadata.labels'))).sort();
-    if (_.isEmpty(labelKeys)) {
-      return { firstLabel: '', groupOptions: specialGroups };
-    }
-
-    const firstLabel = _.first(labelKeys);
-    const groupOptions = _.reduce(labelKeys, (accumulator, key) => ({
-      ...accumulator,
-      [key]: key,
-    }), specialGroups);
-    return { firstLabel, groupOptions };
+  getLabels(items: OverviewItem[]): string[] {
+    const labelSet = new Set<string>();
+    _.each(items, (i: OverviewItem) => {
+      const itemLabels = _.get(i, 'obj.metadata.labels') as K8sResourceKind['metadata']['labels'];
+      _.each(itemLabels, (v: string, k: string) => labelSet.add(k));
+    });
+    return [...labelSet].sort();
   }
 
-  getPodsForResource(resource: K8sResourceKind): K8sResourceKind[] {
+  getPodsForResource(resource: K8sResourceKind): PodKind[] {
     const {pods} = this.props;
     return getOwnedResources(resource, pods.data);
   }
@@ -596,10 +539,10 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     });
   }
 
-  getPodTemplate(resource: K8sResourceKind) {
+  getPodTemplate(resource: K8sResourceKind): PodTemplate {
     switch (resource.kind) {
       case 'Pod':
-        return resource;
+        return resource as PodKind;
       case 'DeploymentConfig':
         // Include labels automatically added to deployment config pods since a service
         // might select them.
@@ -617,7 +560,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
 
   getServicesForResource(resource: K8sResourceKind): K8sResourceKind[] {
     const {services} = this.props;
-    const template = this.getPodTemplate(resource);
+    const template: PodTemplate = this.getPodTemplate(resource);
     return _.filter(services.data, (service: K8sResourceKind) => {
       const selector = new LabelSelector(_.get(service, 'spec.selector', {}));
       return selector.matches(template);
@@ -734,7 +677,10 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       const services = this.getServicesForResource(obj);
       const routes = this.getRoutesForServices(services);
       const pods = this.getPodsForResource(obj);
-      const alerts = combinePodAlerts(pods);
+      const alerts = {
+        ...combinePodAlerts(pods),
+        ...getBuildAlerts(buildConfigs),
+      };
       const status = <OverviewItemReadiness
         desired={obj.status.desiredNumberScheduled}
         ready={obj.status.currentNumberScheduled}
@@ -760,7 +706,6 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
         apiVersion: apiVersionForModel(DeploymentModel),
         kind: DeploymentModel.kind,
       };
-      const alerts = getResourcePausedAlert(obj);
       const replicaSets = this.getReplicaSetsForResource(obj);
       const current = _.head(replicaSets);
       const previous = _.nth(replicaSets, 1);
@@ -768,6 +713,10 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       const buildConfigs = this.getBuildConfigsForResource(obj);
       const services = this.getServicesForResource(obj);
       const routes = this.getRoutesForServices(services);
+      const alerts = {
+        ...getResourcePausedAlert(obj),
+        ...getBuildAlerts(buildConfigs),
+      };
       // TODO: Show pod status for previous and next revisions.
       const status = isRollingOut
         ? <span className="text-muted">Rollout in progress...</span>
@@ -776,18 +725,23 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
           ready={obj.status.replicas}
           resource={current ? current.obj : obj}
         />;
-
-      return {
+      let overviewItems = {
         alerts,
         buildConfigs,
         current,
         isRollingOut,
         obj,
         previous,
+        pods: [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])],
         routes,
         services,
         status,
       };
+
+      this.props.utils.forEach(element => {
+        overviewItems = {...overviewItems, ...element(obj, this.props)};
+      });
+      return overviewItems;
     });
   }
 
@@ -799,7 +753,6 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
         apiVersion: apiVersionForModel(DeploymentConfigModel),
         kind: DeploymentConfigModel.kind,
       };
-      const alerts = getResourcePausedAlert(obj);
       const replicationControllers = this.getReplicationControllersForResource(obj);
       const current = _.head(replicationControllers);
       const previous = _.nth(replicationControllers, 1);
@@ -807,6 +760,10 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       const buildConfigs = this.getBuildConfigsForResource(obj);
       const services = this.getServicesForResource(obj);
       const routes = this.getRoutesForServices(services);
+      const alerts = {
+        ...getResourcePausedAlert(obj),
+        ...getBuildAlerts(buildConfigs),
+      };
 
       // TODO: Show pod status for previous and next revisions.
       const status = isRollingOut
@@ -823,6 +780,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
         isRollingOut,
         obj,
         previous,
+        pods: [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])],
         routes,
         services,
         status,
@@ -840,7 +798,10 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       };
       const buildConfigs = this.getBuildConfigsForResource(obj);
       const pods = this.getPodsForResource(obj);
-      const alerts = combinePodAlerts(pods);
+      const alerts = {
+        ...combinePodAlerts(pods),
+        ...getBuildAlerts(buildConfigs),
+      };
       const services = this.getServicesForResource(obj);
       const routes = this.getRoutesForServices(services);
       const status = <OverviewItemReadiness
@@ -864,7 +825,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
   createPodItems(): OverviewItem[] {
     const {pods} = this.props;
     return _.reduce(pods.data, (acc, pod) => {
-      const obj: K8sResourceKind = {
+      const obj: PodKind = {
         ...pod,
         apiVersion: apiVersionForModel(PodModel),
         kind: PodModel.kind,
@@ -892,8 +853,8 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     }, []);
   }
 
-  createOverviewData(): void {
-    const {loaded, mock, selectedGroup, updateGroupOptions, updateSelectedGroup, updateResources} = this.props;
+  createOverviewData(): OverviewMainContentState {
+    const {loaded, mock, selectedGroup, updateLabels, updateSelectedGroup, updateResources} = this.props;
 
     if (!loaded) {
       return;
@@ -914,41 +875,49 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     updateResources(items);
 
     const filteredItems = this.filterItems(items);
-    const { firstLabel, groupOptions } = this.getGroupOptionsFromLabels(filteredItems);
-    if (!_.has(groupOptions, selectedGroup)) {
+    const labels = this.getLabels(filteredItems);
+    if (selectedGroup !== OverviewSpecialGroup.GROUP_BY_APPLICATION && selectedGroup !== OverviewSpecialGroup.GROUP_BY_RESOURCE && !_.includes(labels, selectedGroup)) {
       updateSelectedGroup(OverviewSpecialGroup.GROUP_BY_APPLICATION);
     }
 
-    updateGroupOptions(groupOptions);
+    updateLabels(labels);
     const groupedItems = groupItems(filteredItems, selectedGroup);
-    this.setState({
+    return {
       filteredItems,
       groupedItems,
-      firstLabel,
       items,
-    });
+    };
   }
 
   render() {
-    const {loaded, loadError, mock, title, project = {}, selectedView} = this.props;
-    const {filteredItems, groupedItems, firstLabel} = this.state;
+    const {loaded, loadError, project, namespace} = this.props;
+    const {filteredItems, groupedItems} = this.state;
+    const OverviewEmptyState = () => <MsgBox
+      title="No Workloads Found."
+      detail={<div>
+        <Link to={UIActions.formatNamespacedRouteForResource('import', namespace)}>Import YAML</Link> or <Link to={`/add/ns/${namespace}`}>add other content</Link> to your project.
+      </div>}
+    />;
+
+    const skeletonOverview = <div className="skeleton-overview">
+      <div className="skeleton-overview--head" />
+      <div className="skeleton-overview--tile" />
+      <div className="skeleton-overview--tile" />
+      <div className="skeleton-overview--tile" />
+    </div>;
+
     return <div className="co-m-pane">
-      <OverviewHeading
-        disabled={mock}
-        firstLabel={firstLabel}
-        title={title}
-        project={project.data}
-      />
+      <OverviewHeading project={_.get(project, 'data')} />
       <div className="co-m-pane__body co-m-pane__body--no-top-margin">
         <StatusBox
-          data={selectedView === OverviewViewOption.RESOURCES ? filteredItems : project}
+          skeleton={skeletonOverview}
+          data={filteredItems}
           label="Resources"
           loaded={loaded}
           loadError={loadError}
           EmptyMsg={OverviewEmptyState}
         >
-          {selectedView === OverviewViewOption.RESOURCES && <ProjectOverview groups={groupedItems} />}
-          {selectedView === OverviewViewOption.DASHBOARD && <OverviewNamespaceDashboard obj={project.data} />}
+          <ProjectOverview groups={groupedItems} />
         </StatusBox>
       </div>
     </div>;
@@ -957,12 +926,13 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
 
 const OverviewMainContent = connect<OverviewMainContentPropsFromState, OverviewMainContentPropsFromDispatch, OverviewMainContentOwnProps>(mainContentStateToProps, mainContentDispatchToProps)(OverviewMainContent_);
 
-const overviewStateToProps = ({UI}): OverviewPropsFromState => {
+const overviewStateToProps = ({UI,FLAGS}): OverviewPropsFromState => {
   const selectedUID = UI.getIn(['overview', 'selectedUID']);
   const resources = UI.getIn(['overview', 'resources']);
+  const resourceList = plugins.registry.getOverviewCRDs().filter(resource => FLAGS.get(resource.properties.required));
   const selectedItem = !!resources && resources.get(selectedUID);
-  const selectedView = UI.getIn(['overview', 'selectedView'], OverviewViewOption.RESOURCES);
-  return { selectedItem, selectedView };
+  return { selectedItem , resourceList};
+
 };
 
 const overviewDispatchToProps = (dispatch): OverviewPropsFromDispatch => {
@@ -971,11 +941,26 @@ const overviewDispatchToProps = (dispatch): OverviewPropsFromDispatch => {
   };
 };
 
-const Overview_: React.SFC<OverviewProps> = ({mock, namespace, selectedItem, selectedView, title, dismissDetails}) => {
-  const sidebarOpen = !_.isEmpty(selectedItem) && selectedView !== OverviewViewOption.DASHBOARD;
+const Overview_: React.SFC<OverviewProps> = ({mock, match, selectedItem, resourceList, title, dismissDetails}) => {
+  const namespace = _.get(match, 'params.name');
+  const sidebarOpen = !_.isEmpty(selectedItem);
   const className = classnames('overview', {'overview--sidebar-shown': sidebarOpen});
+  const ref = React.useRef();
+  const [height, setHeight] = React.useState(500);
+  const calcHeight = (node) => {
+    setHeight(document.getElementsByClassName('pf-c-page')[0].getBoundingClientRect().bottom - node.current.getBoundingClientRect().top);
+  };
+  React.useLayoutEffect(() => {
+    calcHeight(ref);
+    const handleResize = () => calcHeight(ref);
+    window.addEventListener('resize', handleResize);
+    return () => {
+      window.removeEventListener('resize', handleResize);
+    };
+  });
+
   // TODO: Update resources for native Kubernetes clusters.
-  const resources = [
+  let resources: FirehoseResource[] = [
     {
       isList: true,
       kind: 'Build',
@@ -1049,9 +1034,14 @@ const Overview_: React.SFC<OverviewProps> = ({mock, namespace, selectedItem, sel
       prop: 'statefulSets',
     },
   ];
+  let crdUtils = [];
+  resourceList.forEach(resource => {
+    resources = [...resources, ...resource.properties.resources(namespace)];
+    crdUtils = [...crdUtils, resource.properties.utils];
+  });
 
   return <div className={className}>
-    <div className="overview__main-column">
+    <div className="overview__main-column" ref={ref} style={{height}}>
       <div className="overview__main-column-section">
         <Firehose resources={mock ? [] : resources} forceUpdate>
           <OverviewMainContent
@@ -1059,6 +1049,7 @@ const Overview_: React.SFC<OverviewProps> = ({mock, namespace, selectedItem, sel
             namespace={namespace}
             selectedItem={selectedItem}
             title={title}
+            utils={crdUtils}
           />
         </Firehose>
       </div>
@@ -1068,7 +1059,7 @@ const Overview_: React.SFC<OverviewProps> = ({mock, namespace, selectedItem, sel
       <CSSTransition
         appear={true} in timeout={225} classNames="overview__sidebar">
         <div className="overview__sidebar">
-          <div className="overview__sidebar-dismiss clearfix">
+          <div className="co-sidebar-dismiss clearfix">
             <CloseButton onClick={dismissDetails} />
           </div>
           <ResourceOverviewPage
@@ -1083,33 +1074,6 @@ const Overview_: React.SFC<OverviewProps> = ({mock, namespace, selectedItem, sel
 
 export const Overview = connect<OverviewPropsFromState, OverviewPropsFromDispatch, OverviewOwnProps>(overviewStateToProps, overviewDispatchToProps)(Overview_);
 
-export const OverviewPage = withStartGuide(
-  ({match, noProjectsAvailable}: OverviewPageProps & WithStartGuideProps) => {
-    const namespace = _.get(match, 'params.ns');
-    const title = 'Project Status';
-    return <React.Fragment>
-      <Helmet>
-        <title>{title}</title>
-      </Helmet>
-      <Overview
-        mock={noProjectsAvailable}
-        namespace={namespace}
-        title={title}
-      />
-    </React.Fragment>;
-  }
-);
-
-type FirehoseItem = {
-  data?: K8sResourceKind;
-  [key: string]: any;
-};
-
-type FirehoseList = {
-  data?: K8sResourceKind[];
-  [key: string]: any;
-};
-
 type OverviewItemAlerts = {
   [key: string]: {
     message: string;
@@ -1122,7 +1086,7 @@ export type PodControllerOverviewItem = {
   revision: number;
   obj: K8sResourceKind;
   phase?: string;
-  pods: K8sResourceKind[];
+  pods: PodKind[];
 };
 
 export type BuildConfigOverviewItem = K8sResourceKind & {
@@ -1135,13 +1099,20 @@ export type OverviewItem = {
   current?: PodControllerOverviewItem;
   isRollingOut?: boolean;
   obj: K8sResourceKind;
-  pods?: K8sResourceKind[];
+  pods?: PodKind[];
   previous?: PodControllerOverviewItem;
   routes: K8sResourceKind[];
   services: K8sResourceKind[];
   status?: React.ReactNode;
+  ksroutes?: K8sResourceKind[];
+  configurations?: K8sResourceKind[];
+  revisions?: K8sResourceKind[];
 };
 
+export type PodOverviewItem = {
+  obj: PodKind;
+} & OverviewItem;
+
 export type OverviewGroup = {
   name: string;
   items: OverviewItem[];
@@ -1164,21 +1135,16 @@ type OverviewItemReadinessProps = {
 
 type OverviewHeadingPropsFromState = {
   filterValue: string;
-  groupOptions: {[key: string]: string};
+  labels: string[];
   selectedGroup: string;
-  selectedView: OverviewViewOption;
 };
 
 type OverviewHeadingPropsFromDispatch = {
-  selectView: (view: OverviewViewOption) => void;
-  selectGroup: (selectedLabel: string) => void;
+  selectGroup: (selectedLabel: OverviewSpecialGroup) => void;
   changeFilter: (value: string) => void;
 };
 
 type OverviewHeadingOwnProps = {
-  disabled?: boolean;
-  firstLabel?: string;
-  title: string;
   project: K8sResourceKind;
 };
 
@@ -1186,52 +1152,51 @@ type OverviewHeadingProps = OverviewHeadingPropsFromState & OverviewHeadingProps
 
 type OverviewMainContentPropsFromState = {
   filterValue: string;
-  groupOptions: {[key: string]: string};
+  labels: string[];
   metrics: OverviewMetrics;
   selectedGroup: string;
-  selectedView: OverviewViewOption;
 };
 
 type OverviewMainContentPropsFromDispatch = {
-  updateGroupOptions: (groups: {[key: string]:string}) => void;
+  updateLabels: (labels: string[]) => void;
   updateMetrics: (metrics: OverviewMetrics) => void;
   updateResources: (items: OverviewItem[]) => void;
-  updateSelectedGroup: (group: string) => void;
+  updateSelectedGroup: (group: OverviewSpecialGroup) => void;
 };
 
 type OverviewMainContentOwnProps = {
-  builds?: FirehoseList;
-  buildConfigs?: FirehoseList;
-  daemonSets?: FirehoseList;
-  deploymentConfigs?: FirehoseList;
-  deployments?: FirehoseList;
+  builds?: FirehoseResult;
+  buildConfigs?: FirehoseResult;
+  daemonSets?: FirehoseResult;
+  deploymentConfigs?: FirehoseResult;
+  deployments?: FirehoseResult;
   mock: boolean;
   loaded?: boolean;
   loadError?: any;
   namespace: string;
-  pods?: FirehoseList;
-  project?: FirehoseItem;
-  replicationControllers?: FirehoseList;
-  replicaSets?: FirehoseList;
-  routes?: FirehoseList;
-  services?: FirehoseList;
+  pods?: FirehoseResult<PodKind[]>;
+  project?: FirehoseResult<K8sResourceKind>;
+  replicationControllers?: FirehoseResult;
+  replicaSets?: FirehoseResult;
+  routes?: FirehoseResult;
+  services?: FirehoseResult;
   selectedItem: OverviewItem;
-  statefulSets?: FirehoseList;
+  statefulSets?: FirehoseResult;
   title?: string;
+  utils?: Function[];
 };
 
-type OverviewMainContentProps = OverviewMainContentPropsFromState & OverviewMainContentPropsFromDispatch & OverviewMainContentOwnProps;
+export type OverviewMainContentProps = OverviewMainContentPropsFromState & OverviewMainContentPropsFromDispatch & OverviewMainContentOwnProps;
 
 type OverviewMainContentState = {
   readonly items: any[];
   readonly filteredItems: any[];
   readonly groupedItems: any[];
-  readonly firstLabel: string;
 };
 
 type OverviewPropsFromState = {
   selectedItem: any;
-  selectedView: OverviewViewOption;
+  resourceList: OverviewCRD[];
 };
 
 type OverviewPropsFromDispatch = {
@@ -1240,12 +1205,8 @@ type OverviewPropsFromDispatch = {
 
 type OverviewOwnProps = {
   mock: boolean;
-  namespace: string;
+  match: any;
   title: string;
 };
 
 type OverviewProps = OverviewPropsFromState & OverviewPropsFromDispatch & OverviewOwnProps;
-
-type OverviewPageProps = {
-  match: any;
-};
