@@ -1,16 +1,18 @@
-/* eslint-disable no-undef, no-unused-vars */
 import * as _ from 'lodash-es';
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { Base64 } from 'js-base64';
+import { ActionGroup, Button } from '@patternfly/react-core';
+import { MinusCircleIcon, PlusCircleIcon } from '@patternfly/react-icons';
 
 import { k8sCreate, k8sUpdate, K8sResourceKind, referenceFor } from '../../module/k8s';
 import { ButtonBar, Firehose, history, StatusBox, LoadingBox, Dropdown, resourceObjPath } from '../utils';
+import { ModalBody, ModalTitle, ModalSubmitFooter } from '../factory/modal';
 import { AsyncComponent } from '../utils/async';
 import { SecretModel } from '../../models';
 import { WebHookSecretKey } from '../secret';
 
-enum SecretTypeAbstraction {
+export enum SecretTypeAbstraction {
   generic = 'generic',
   source = 'source',
   image = 'image',
@@ -88,7 +90,7 @@ const generateSecret = () => {
 };
 
 // withSecretForm returns SubForm which is a Higher Order Component for all the types of secret forms.
-const withSecretForm = (SubForm) => class SecretFormComponent extends React.Component<BaseEditSecretProps_, BaseEditSecretState_> {
+export const withSecretForm = (SubForm, modal?: boolean) => class SecretFormComponent extends React.Component<BaseEditSecretProps_, BaseEditSecretState_> {
   constructor(props) {
     super(props);
     const existingSecret = _.pick(props.obj, ['metadata', 'type']);
@@ -154,33 +156,36 @@ const withSecretForm = (SubForm) => class SecretFormComponent extends React.Comp
       : k8sUpdate(SecretModel, newSecret, metadata.namespace, newSecret.metadata.name)
     ).then(secret => {
       this.setState({inProgress: false});
-      history.push(resourceObjPath(secret, referenceFor(secret)));
+      if (this.props.onSave) {
+        this.props.onSave(secret.metadata.name);
+      }
+      if (!modal) {
+        history.push(resourceObjPath(secret, referenceFor(secret)));
+      }
     }, err => this.setState({error: err.message, inProgress: false}));
   }
-  render() {
-    const { secretTypeAbstraction } = this.state;
-    const { onCancel = history.goBack } = this.props;
-    const title = `${this.props.titleVerb} ${secretDisplayType(secretTypeAbstraction)} Secret`;
-    return <div className="co-m-pane__body">
-      <Helmet>
-        <title>{title}</title>
-      </Helmet>
-      <form className="co-m-pane__body-group co-create-secret-form co-m-pane__form" onSubmit={this.save}>
-        <h1 className="co-m-pane__heading">{title}</h1>
-        <p className="co-m-pane__explanation">{this.props.explanation}</p>
 
+  renderBody = () => {
+    return (
+      <React.Fragment>
         <fieldset disabled={!this.props.isCreate}>
           <div className="form-group">
-            <label className="control-label co-required" htmlFor="secret-name">Secret Name</label>
+            <label className="control-label co-required" htmlFor="secret-name">
+              Secret Name
+            </label>
             <div>
-              <input className="form-control"
+              <input
+                className="pf-c-form-control"
                 type="text"
                 onChange={this.onNameChanged}
                 value={this.state.secret.metadata.name}
                 aria-describedby="secret-name-help"
                 id="secret-name"
-                required />
-              <p className="help-block" id="secret-name-help">Unique name of the new secret.</p>
+                required
+              />
+              <p className="help-block" id="secret-name-help">
+                Unique name of the new secret.
+              </p>
             </div>
           </div>
         </fieldset>
@@ -192,12 +197,55 @@ const withSecretForm = (SubForm) => class SecretFormComponent extends React.Comp
           secretType={this.state.secret.type}
           isCreate={this.props.isCreate}
         />
-        <ButtonBar errorMessage={this.state.error} inProgress={this.state.inProgress}>
-          <button type="submit" disabled={this.state.disableForm} className="btn btn-primary" id="save-changes">{this.props.saveButtonText || 'Create'}</button>
-          <button type="button" className="btn btn-default" id="cancel" onClick={onCancel}>Cancel</button>
-        </ButtonBar>
+      </React.Fragment>
+    );
+  }
+
+  render() {
+    const { secretTypeAbstraction } = this.state;
+    const { onCancel = history.goBack } = this.props;
+    const title = `${this.props.titleVerb} ${secretDisplayType(secretTypeAbstraction)} Secret`;
+    return modal ? (
+      <form className="co-create-secret-form modal-content" onSubmit={this.save}>
+        <ModalTitle>{title}</ModalTitle>
+        <ModalBody>{this.renderBody()}</ModalBody>
+        <ModalSubmitFooter
+          errorMessage={this.state.error || ''}
+          inProgress={this.state.inProgress}
+          submitText="Create"
+          cancel={this.props.onCancel}
+        />
       </form>
-    </div>;
+    ) : (
+      <div className="co-m-pane__body">
+        <Helmet>
+          <title>{title}</title>
+        </Helmet>
+        <form
+          className="co-m-pane__body-group co-create-secret-form co-m-pane__form"
+          onSubmit={this.save}
+        >
+          <h1 className="co-m-pane__heading">{title}</h1>
+          <p className="co-m-pane__explanation">{this.props.explanation}</p>
+          {this.renderBody()}
+          <ButtonBar errorMessage={this.state.error} inProgress={this.state.inProgress}>
+            <ActionGroup className="pf-c-form">
+              <Button
+                type="submit"
+                isDisabled={this.state.disableForm}
+                variant="primary"
+                id="save-changes"
+              >
+                {this.props.saveButtonText || 'Create'}
+              </Button>
+              <Button type="button" variant="secondary" id="cancel" onClick={onCancel}>
+                Cancel
+              </Button>
+            </ActionGroup>
+          </ButtonBar>
+        </form>
+      </div>
+    );
   }
 };
 
@@ -223,7 +271,7 @@ const getImageSecretType = (secretKey: string): SecretType => {
   }
 };
 
-class ImageSecretForm extends React.Component<ImageSecretFormProps, ImageSecretFormState> {
+export class ImageSecretForm extends React.Component<ImageSecretFormProps, ImageSecretFormState> {
   constructor(props) {
     super(props);
     const data = this.props.isCreate ? {'.dockerconfigjson': '{}'} : this.props.stringData;
@@ -345,7 +393,7 @@ class ConfigEntryForm extends React.Component<ConfigEntryFormProps, ConfigEntryF
       <div className="form-group">
         <label className="control-label co-required" htmlFor={`${this.props.id}-address`}>Registry Server Address</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id={`${this.props.id}-address`}
             type="text"
             name="address"
@@ -357,7 +405,7 @@ class ConfigEntryForm extends React.Component<ConfigEntryFormProps, ConfigEntryF
       <div className="form-group">
         <label className="control-label co-required" htmlFor={`${this.props.id}-username`}>Username</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id={`${this.props.id}-username`}
             type="text"
             name="username"
@@ -369,7 +417,7 @@ class ConfigEntryForm extends React.Component<ConfigEntryFormProps, ConfigEntryF
       <div className="form-group">
         <label className="control-label co-required" htmlFor={`${this.props.id}-password`}>Password</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id={`${this.props.id}-password`}
             type="password"
             name="password"
@@ -381,7 +429,7 @@ class ConfigEntryForm extends React.Component<ConfigEntryFormProps, ConfigEntryF
       <div className="form-group">
         <label className="control-label" htmlFor={`${this.props.id}-email`}>Email</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id={`${this.props.id}-email`}
             type="text"
             name="email"
@@ -495,9 +543,12 @@ class CreateConfigSubform extends React.Component<CreateConfigSubformProps, Crea
     const secretEntriesList = _.map(this.state.secretEntriesArray, (entryData, index) => {
       return <div className="co-create-secret__form-entry-wrapper" key={entryData.uid}>
         {_.size(this.state.secretEntriesArray) > 1 && <div className="co-create-secret-form__link--remove-entry">
-          <button className="btn btn-link" type="button" onClick={() => this.removeEntry(index)}>
-            <i className="fa fa-minus-circle" aria-hidden="true" /> Remove Credentials
-          </button>
+          <Button
+            onClick={() => this.removeEntry(index)}
+            type="button"
+            variant="link">
+            <MinusCircleIcon className="co-icon-space-r" />Remove Credentials
+          </Button>
         </div>}
         <ConfigEntryForm id={index} entry={entryData.entry} onChange={this.onDataChanged} />
       </div>;
@@ -505,9 +556,13 @@ class CreateConfigSubform extends React.Component<CreateConfigSubformProps, Crea
     return (
       <React.Fragment>
         {secretEntriesList}
-        <button className="btn btn-link co-create-secret-form__link--add-entry" type="button" onClick={() => this.addEntry()}>
-          <i className="fa fa-plus-circle" aria-hidden="true" /> Add Credentials
-        </button>
+        <Button
+          className="co-create-secret-form__link--add-entry pf-m-link--align-left"
+          onClick={() => this.addEntry()}
+          type="button"
+          variant="link">
+          <PlusCircleIcon className="co-icon-space-r" />Add Credentials
+        </Button>
       </React.Fragment>
     );
   }
@@ -575,8 +630,8 @@ class WebHookSecretForm extends React.Component<WebHookSecretFormProps, WebHookS
   render() {
     return <div className="form-group">
       <label className="control-label co-required" htmlFor="webhook-secret-key">Webhook Secret Key</label>
-      <div className="input-group">
-        <input className="form-control"
+      <div className="pf-c-input-group">
+        <input className="pf-c-form-control"
           id="webhook-secret-key"
           type="text"
           name="webhookSecretKey"
@@ -584,16 +639,14 @@ class WebHookSecretForm extends React.Component<WebHookSecretFormProps, WebHookS
           value={this.state.stringData.WebHookSecretKey}
           aria-describedby="webhook-secret-help"
           required />
-        <span className="input-group-btn">
-          <button type="button" onClick={this.generateWebHookSecret} className="btn btn-default">Generate</button>
-        </span>
+        <button type="button" onClick={this.generateWebHookSecret} className="pf-c-button pf-m-tertiary">Generate</button>
       </div>
       <p className="help-block" id="webhook-secret-help">Value of the secret will be supplied when invoking the webhook. </p>
     </div>;
   }
 }
 
-class SourceSecretForm extends React.Component<SourceSecretFormProps, SourceSecretFormState> {
+export class SourceSecretForm extends React.Component<SourceSecretFormProps, SourceSecretFormState> {
   constructor(props) {
     super(props);
     this.state = {
@@ -656,7 +709,7 @@ export class BasicAuthSubform extends React.Component<BasicAuthSubformProps, Bas
       <div className="form-group">
         <label className="control-label" htmlFor="username">Username</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id="username"
             aria-describedby="username-help"
             type="text"
@@ -669,7 +722,7 @@ export class BasicAuthSubform extends React.Component<BasicAuthSubformProps, Bas
       <div className="form-group">
         <label className="control-label co-required" htmlFor="password">Password or Token</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id="password"
             aria-describedby="password-help"
             type="password"
@@ -686,7 +739,7 @@ export class BasicAuthSubform extends React.Component<BasicAuthSubformProps, Bas
 
 const DroppableFileInput = (props) => <AsyncComponent loader={() => import('../utils/file-input').then(c => c.DroppableFileInput)} {...props} />;
 
-class SSHAuthSubform extends React.Component<SSHAuthSubformProps, SSHAuthSubformState> {
+export class SSHAuthSubform extends React.Component<SSHAuthSubformProps, SSHAuthSubformState> {
   constructor(props) {
     super(props);
     this.state = {
@@ -812,9 +865,12 @@ class GenericSecretForm extends React.Component<GenericSecretFormProps, GenericS
     const secretEntriesList = _.map(this.state.secretEntriesArray, (entryData, index) => {
       return <div className="co-create-secret__form-entry-wrapper" key={entryData.uid}>
         {_.size(this.state.secretEntriesArray) > 1 && <div className="co-create-secret-form__link--remove-entry">
-          <button className="btn btn-link" type="button" onClick={() => this.removeEntry(index)}>
-            <i className="fa fa-minus-circle" aria-hidden="true" /> Remove Key/Value
-          </button>
+          <Button
+            type="button"
+            onClick={() => this.removeEntry(index)}
+            variant="link">
+            <MinusCircleIcon className="co-icon-space-r" />Remove Key/Value
+          </Button>
         </div>}
         <KeyValueEntryForm id={index} entry={entryData.entry} onChange={this.onDataChanged} />
       </div>;
@@ -822,9 +878,13 @@ class GenericSecretForm extends React.Component<GenericSecretFormProps, GenericS
     return (
       <React.Fragment>
         {secretEntriesList}
-        <button className="btn btn-link co-create-secret-form__link--add-entry" type="button" onClick={() => this.addEntry()}>
-          <i className="fa fa-plus-circle" aria-hidden="true" /> Add Key/Value
-        </button>
+        <Button
+          className="co-create-secret-form__link--add-entry pf-m-link--align-left"
+          onClick={() => this.addEntry()}
+          type="button"
+          variant="link">
+          <PlusCircleIcon className="co-icon-space-r" />Add Key/Value
+        </Button>
       </React.Fragment>
     );
   }
@@ -855,7 +915,7 @@ class KeyValueEntryForm extends React.Component<KeyValueEntryFormProps, KeyValue
       <div className="form-group">
         <label className="control-label co-required" htmlFor={`${this.props.id}-key`}>Key</label>
         <div>
-          <input className="form-control"
+          <input className="pf-c-form-control"
             id={`${this.props.id}-key`}
             type="text"
             name="key"
@@ -998,8 +1058,9 @@ type BaseEditSecretProps_ = {
   titleVerb: string;
   secretTypeAbstraction?: SecretTypeAbstraction;
   saveButtonText?: string;
-  explanation: string;
-  onCancel?: () => null;
+  explanation?: string;
+  onCancel?: () => void;
+  onSave?: (name: string) => void;
 };
 
 type BasicAuthSubformProps = {
