@@ -5,7 +5,7 @@ import * as classNames from 'classnames';
 import * as fuzzy from 'fuzzysearch';
 import * as _ from 'lodash-es';
 import { Form, FormControl, FormGroup, HelpBlock } from 'patternfly-react';
-
+import { ActionGroup, Button } from '@patternfly/react-core';
 import {
   AsyncComponent,
   ButtonBar,
@@ -16,7 +16,7 @@ import {
 } from './utils';
 import { Firehose } from './utils/firehose';
 import { k8sCreate } from './../module/k8s';
-import actions from './../module/k8s/k8s-actions';
+import * as k8sActions from '../actions/k8s';
 import { StorageClassModel } from './../models';
 
 const NameValueEditorComponent = (props) => <AsyncComponent loader={() => import('./utils/name-value-editor').then(c => c.NameValueEditor)} {...props} />;
@@ -36,7 +36,6 @@ const defaultState = {
   fieldErrors: {parameters: {}},
 };
 
-/*eslint-disable no-undef*/
 export class StorageClassForm_ extends React.Component<StorageClassFormProps, StorageClassFormState> {
 
   resources: Resources;
@@ -751,6 +750,7 @@ export class StorageClassForm_ extends React.Component<StorageClassFormProps, St
               </label>
               <FormControl
                 type="text"
+                bsClass="pf-c-form-control"
                 value={_.get(this.state, `newStorageClass.parameters.${key}.value`, '')}
                 onChange={(event) => this.setParameterHandler(key, event, isCheckbox)} />
             </React.Fragment>
@@ -810,6 +810,7 @@ export class StorageClassForm_ extends React.Component<StorageClassFormProps, St
             <label className="control-label co-required" htmlFor="storage-class-name">Name</label>
             <FormControl
               type="text"
+              bsClass="pf-c-form-control"
               placeholder={newStorageClass.name}
               id="storage-class-name"
               onChange={(event) => this.setStorageHandler('name', event.target.value)}
@@ -821,6 +822,7 @@ export class StorageClassForm_ extends React.Component<StorageClassFormProps, St
             <label htmlFor="storage-class-description">Description</label>
             <FormControl
               type="text"
+              bsClass="pf-c-form-control"
               id="storage-class-description"
               onChange={(event) => this.setStorageHandler('description', event.target.value)}
               value={_.get(newStorageClass, 'description', '')} />
@@ -858,21 +860,23 @@ export class StorageClassForm_ extends React.Component<StorageClassFormProps, St
           </div>
 
           <ButtonBar errorMessage={this.state.error ? this.state.error.message : ''} inProgress={this.state.loading}>
-            <button
-              type="submit"
-              className="btn btn-primary"
-              id="save-changes"
-              disabled={!this.state.validationSuccessful}
-              onClick={this.createStorageClass}>
-              Create
-            </button>
-            <button
-              type="button"
-              className="btn btn-default"
-              id="cancel"
-              onClick={() => history.push('/k8s/cluster/storageclasses')}>
-              Cancel
-            </button>
+            <ActionGroup className="pf-c-form">
+              <Button
+                id="save-changes"
+                isDisabled={!this.state.validationSuccessful}
+                onClick={this.createStorageClass}
+                type="submit"
+                variant="primary">
+                Create
+              </Button>
+              <Button
+                id="cancel"
+                onClick={() => history.push('/k8s/cluster/storageclasses')}
+                type="button"
+                variant="secondary">
+                Cancel
+              </Button>
+            </ActionGroup>
           </ButtonBar>
         </Form>
       </div>
@@ -886,8 +890,8 @@ const mapStateToProps = ({k8s}, {onClose}) => ({
 });
 
 const mapDispatchToProps = () => ({
-  stopK8sWatch: actions.stopK8sWatch,
-  watchK8sList: actions.watchK8sList,
+  stopK8sWatch: k8sActions.stopK8sWatch,
+  watchK8sList: k8sActions.watchK8sList,
 });
 
 export type StorageClassFormProps = {
@@ -938,7 +942,5 @@ export const StorageClassForm = props => {
     </Firehose>
   );
 };
+
 ConnectedStorageClassForm.displayName='StorageClassForm';
-
-
-/* eslint-enable no-undef */
