@@ -4,6 +4,8 @@ import * as _ from 'lodash-es';
 import * as classNames from 'classnames';
 import { DragSource, DropTarget } from 'react-dnd';
 import { DRAGGABLE_TYPE } from './draggable-item-types';
+import { Button } from '@patternfly/react-core';
+import { PficonDragdropIcon, MinusCircleIcon, PlusCircleIcon } from '@patternfly/react-icons';
 
 import { NameValueEditorPair, EnvFromPair, EnvType } from './index';
 import { ValueFromPair } from './value-from-pair';
@@ -20,9 +22,9 @@ export const NameValueEditor = withDragDropContext(class NameValueEditor extends
   }
 
   _append() {
-    const {updateParentData, nameValuePairs, nameValueId, allowSorting} = this.props;
+    const {updateParentData, nameValuePairs, nameValueId} = this.props;
 
-    updateParentData({nameValuePairs: allowSorting ? nameValuePairs.concat([['', '', nameValuePairs.length]]) : nameValuePairs.concat([['', '']])}, nameValueId);
+    updateParentData({nameValuePairs: nameValuePairs.concat([['', '', nameValuePairs.length]])}, nameValueId);
   }
 
   _appendConfigMapOrSecret() {
@@ -35,8 +37,9 @@ export const NameValueEditor = withDragDropContext(class NameValueEditor extends
     const {updateParentData, nameValueId} = this.props;
     const nameValuePairs = _.cloneDeep(this.props.nameValuePairs);
     nameValuePairs.splice(i, 1);
+    nameValuePairs.forEach((values, index) => values[2] = index); // update the indices in order.
 
-    updateParentData({nameValuePairs: nameValuePairs.length ? nameValuePairs : [['', '']]}, nameValueId);
+    updateParentData({nameValuePairs: nameValuePairs.length ? nameValuePairs : [['', '', 0]]}, nameValueId);
   }
 
   _change(e, i, type) {
@@ -65,7 +68,7 @@ export const NameValueEditor = withDragDropContext(class NameValueEditor extends
       return <PairElement onChange={this._change} index={i} nameString={nameString} valueString={valueString} allowSorting={allowSorting} readOnly={readOnly} pair={pair} key={key} onRemove={this._remove} onMove={this._move} rowSourceId={nameValueId} configMaps={configMaps} secrets={secrets} />;
     });
     return <React.Fragment>
-      <div className="row">
+      <div className="row pairs-list__heading">
         {!readOnly && allowSorting && <div className="col-xs-1 co-empty__header"></div>}
         <div className="col-xs-5 text-secondary text-uppercase">{nameString}</div>
         <div className="col-xs-5 text-secondary text-uppercase">{valueString}</div>
@@ -78,17 +81,25 @@ export const NameValueEditor = withDragDropContext(class NameValueEditor extends
             readOnly ?
               null :
               <div className="co-toolbar__group co-toolbar__group--left">
-                <button type="button" className="btn btn-link pairs-list__add-btn" onClick={this._append}>
-                  <i aria-hidden="true" className="fa fa-plus-circle pairs-list__add-icon" />{addString}
-                </button>
+                <Button
+                  className="pf-m-link--align-left"
+                  data-test-id="pairs-list__add-btn"
+                  onClick={this._append}
+                  type="button"
+                  variant="link">
+                  <PlusCircleIcon data-test-id="pairs-list__add-icon" className="co-icon-space-r" />{addString}
+                </Button>
                 {
                   addConfigMapSecret &&
-                    <React.Fragment>
-                      <span aria-hidden="true" className="co-action-divider hidden-xs">|</span>
-                      <button type="button" className="btn btn-link" onClick={this._appendConfigMapOrSecret}>
-                        <i aria-hidden="true" className="fa fa-plus-circle pairs-list__add-icon" />Add from Config Map or Secret
-                      </button>
-                    </React.Fragment>
+                  <React.Fragment>
+                    <Button
+                      className="pf-m-link--align-left"
+                      onClick={this._appendConfigMapOrSecret}
+                      type="button"
+                      variant="link">
+                      <PlusCircleIcon data-test-id="pairs-list__add-icon" className="co-icon-space-r" />Add from Config Map or Secret
+                    </Button>
+                  </React.Fragment>
                 }
               </div>
           }
@@ -178,7 +189,7 @@ export const EnvFromEditor = withDragDropContext(class EnvFromEditor extends Rea
     });
 
     return <React.Fragment>
-      <div className="row">
+      <div className="row pairs-list__heading">
         {!readOnly && <div className="col-xs-1 co-empty__header"></div>}
         <div className="col-xs-5 text-secondary text-uppercase">Config Map/Secret</div>
         <div className="col-xs-5 text-secondary text-uppercase">Prefix (Optional)</div>
@@ -189,9 +200,13 @@ export const EnvFromEditor = withDragDropContext(class EnvFromEditor extends Rea
         <div className="col-xs-12">
           {
             !readOnly &&
-            <button type="button" className="btn-link" onClick={this._append}>
-              <i aria-hidden="true" className="fa fa-plus-circle pairs-list__add-icon" />Add All From Config Map or Secret
-            </button>
+            <Button
+              className="pf-m-link--align-left"
+              onClick={this._append}
+              type="button"
+              variant="link">
+              <PlusCircleIcon /> Add All From Config Map or Secret
+            </Button>
           }
         </div>
       </div>
@@ -310,20 +325,20 @@ const PairElement = DragSource(DRAGGABLE_TYPE.ENV_ROW, pairSource, collectSource
 
   render() {
     const {isDragging, connectDragSource, connectDragPreview, connectDropTarget, nameString, valueString, allowSorting, readOnly, pair, configMaps, secrets} = this.props;
-    const deleteButton = <React.Fragment><i className="fa fa-minus-circle pairs-list__side-btn pairs-list__delete-icon" aria-hidden="true"></i><span className="sr-only">Delete</span></React.Fragment>;
+    const deleteIcon = <React.Fragment><MinusCircleIcon className="pairs-list__side-btn pairs-list__delete-icon" /><span className="sr-only">Delete</span></React.Fragment>;
 
     return connectDropTarget(
       connectDragPreview(
         <div className={classNames('row', isDragging ? 'pairs-list__row-dragging' : 'pairs-list__row')} ref={node => this.node = node}>
           {allowSorting && !readOnly &&
             <div className="col-xs-1 pairs-list__action">
-              {connectDragSource(<button type="button" className="btn btn-link btn-link--inherit-color pairs-list__action-icon" tabIndex="-1">
-                <i className="pficon pficon-drag-drop pairs-list__action-icon--reorder" />
+              {connectDragSource(<button type="button" className="pf-c-button pf-m-plain btn-link--inherit-color pairs-list__action-icon" tabIndex="-1">
+                <PficonDragdropIcon className="pairs-list__action-icon--reorder" />
               </button>)}
             </div>
           }
           <div className="col-xs-5 pairs-list__name-field">
-            <input type="text" className="form-control" placeholder={nameString.toLowerCase()} value={pair[NameValueEditorPair.Name]} onChange={this._onChangeName} disabled={readOnly} />
+            <input type="text" className="pf-c-form-control" placeholder={nameString.toLowerCase()} value={pair[NameValueEditorPair.Name]} onChange={this._onChangeName} disabled={readOnly} />
           </div>
           {
             _.isPlainObject(pair[NameValueEditorPair.Value]) ?
@@ -332,14 +347,14 @@ const PairElement = DragSource(DRAGGABLE_TYPE.ENV_ROW, pairSource, collectSource
               </div>
               :
               <div className="col-xs-5 pairs-list__value-field">
-                <input type="text" className="form-control" placeholder={valueString.toLowerCase()} value={pair[NameValueEditorPair.Value] || ''} onChange={this._onChangeValue} disabled={readOnly} />
+                <input type="text" className="pf-c-form-control" placeholder={valueString.toLowerCase()} value={pair[NameValueEditorPair.Value] || ''} onChange={this._onChangeValue} disabled={readOnly} />
               </div>
           }
           {
             !readOnly &&
-              <div className="col-xs-1">
-                <button type="button" className={classNames('btn', 'btn-link', 'btn-link--inherit-color', {'pairs-list__span-btns': allowSorting})} onClick={this._onRemove}>
-                  {deleteButton}
+              <div className="col-xs-1 pairs-list__action">
+                <button type="button" data-test-id="pairs-list__delete-btn" className={classNames('pf-c-button', 'pf-m-plain', 'btn-link--inherit-color', {'pairs-list__span-btns': allowSorting})} onClick={this._onRemove}>
+                  {deleteIcon}
                 </button>
               </div>
           }
@@ -394,15 +409,15 @@ const EnvFromPairElement = DragSource(DRAGGABLE_TYPE.ENV_FROM_ROW, pairSource, c
 
   render() {
     const {isDragging, connectDragSource, connectDragPreview, connectDropTarget, valueString, readOnly, pair, configMaps, secrets} = this.props;
-    const deleteButton = <React.Fragment><i className="fa fa-minus-circle pairs-list__side-btn pairs-list__delete-icon" aria-hidden="true"></i><span className="sr-only">Delete</span></React.Fragment>;
+    const deleteButton = <React.Fragment><MinusCircleIcon className="pairs-list__side-btn pairs-list__delete-icon" /><span className="sr-only">Delete</span></React.Fragment>;
 
     return connectDropTarget(
       connectDragPreview(
         <div className={classNames('row', isDragging ? 'pairs-list__row-dragging' : 'pairs-list__row')} ref={node => this.node = node}>
           { !readOnly &&
             <div className="col-xs-1 pairs-list__action">
-              {connectDragSource(<button type="button" className="btn btn-link btn-link--inherit-color pairs-list__action-icon" tabIndex="-1">
-                <i className="pficon pficon-drag-drop pairs-list__action-icon--reorder" />
+              {connectDragSource(<button type="button" className="pf-c-button pf-m-plain btn-link--inherit-color pairs-list__action-icon" tabIndex="-1">
+                <PficonDragdropIcon className="pairs-list__action-icon--reorder" />
               </button>)}
             </div>
           }
@@ -410,12 +425,12 @@ const EnvFromPairElement = DragSource(DRAGGABLE_TYPE.ENV_FROM_ROW, pairSource, c
             <ValueFromPair pair={pair[EnvFromPair.Resource]} configMaps={configMaps} secrets={secrets} onChange={this._onChangeResource} disabled={readOnly} />
           </div>
           <div className="col-xs-5 pairs-list__name-field">
-            <input type="text" className="form-control" placeholder={valueString.toLowerCase()} value={pair[EnvFromPair.Prefix]} onChange={this._onChangePrefix} disabled={readOnly} />
+            <input data-test-id="env-prefix" type="text" className="pf-c-form-control" placeholder={valueString.toLowerCase()} value={pair[EnvFromPair.Prefix]} onChange={this._onChangePrefix} disabled={readOnly} />
           </div>
           {
             readOnly ? null :
-              <div className="col-xs-1">
-                <button type="button" className="btn btn-link btn-link--inherit-color pairs-list__span-btns" onClick={this._onRemove}>
+              <div className="col-xs-1 pairs-list__action">
+                <button type="button" className="pf-c-button pf-m-plain btn-link--inherit-color pairs-list__span-btns" onClick={this._onRemove}>
                   {deleteButton}
                 </button>
               </div>
