@@ -1,14 +1,13 @@
-/* eslint-disable no-unused-vars */
-
 import { Map as ImmutableMap } from 'immutable';
 
 import { GroupVersionKind, referenceForModel } from '../module/k8s';
 import * as k8sModels from '../models';
+import * as plugins from '../plugins';
 
 /**
  * Sample YAML manifests for some of the statically-defined Kubernetes models.
  */
-export const yamlTemplates = ImmutableMap<GroupVersionKind, ImmutableMap<string, string>>()
+export const baseTemplates = ImmutableMap<GroupVersionKind, ImmutableMap<string, string>>()
   .setIn(['DEFAULT', 'default'], `
 apiVersion: ''
 kind: ''
@@ -153,16 +152,15 @@ spec:
     imageChange: {}
   - type: ConfigChange
 `).setIn([referenceForModel(k8sModels.ChargebackReportModel), 'default'], `
-apiVersion: chargeback.coreos.com/v1alpha1
+apiVersion: metering.openshift.io/v1alpha1
 kind: Report
 metadata:
   name: namespace-memory-request
-  namespace: default
+  namespace: openshift-metering
 spec:
-  generationQuery: namespace-memory-request
-  gracePeriod: 5m0s
-  reportingStart: '2018-01-01T00:00:00Z'
-  reportingEnd: '2018-12-30T23:59:59Z'
+  query: namespace-memory-request
+  reportingStart: '2019-01-01T00:00:00Z'
+  reportingEnd: '2019-12-30T23:59:59Z'
   runImmediately: true
 `)
   .setIn([referenceForModel(k8sModels.DeploymentModel), 'default'], `
@@ -666,26 +664,6 @@ spec:
   - type: ImageChange
     imageChange: {}
   - type: ConfigChange
-`).setIn([referenceForModel(k8sModels.BuildConfigModel), 'pipeline-build'], `
-apiVersion: build.openshift.io/v1
-kind: BuildConfig
-metadata:
-  labels:
-    name: pipeline-build
-  name: pipeline-build
-  namespace: default
-spec:
-  strategy:
-    jenkinsPipelineStrategy:
-      jenkinsfile: |-
-        node('nodejs') {
-          stage('build') {
-            sh 'npm --version'
-          }
-        }
-    type: JenkinsPipeline
-  triggers:
-  - type: ConfigChange
 `).setIn([referenceForModel(k8sModels.ClusterServiceBrokerModel), 'default'], `
 apiVersion: servicecatalog.k8s.io/v1beta1
 kind: ClusterServiceBroker
@@ -714,14 +692,14 @@ metadata:
 spec:
   hard:
     requests.storage: 100Gi
-    persistentvolumeclaims: 100
+    persistentvolumeclaims: '100'
     # For quota specific to a storage class, the storage class must have the same name
     gold.storage-class.kubernetes.io/requests.storage: 3Gi
-    gold.storage-class.kubernetes.io/persistentvolumeclaims: 5
+    gold.storage-class.kubernetes.io/persistentvolumeclaims: '5'
     silver.storage-class.kubernetes.io/requests.storage: 2Gi
-    silver.storage-class.kubernetes.io/persistentvolumeclaims: 3
+    silver.storage-class.kubernetes.io/persistentvolumeclaims: '3'
     bronze.storage-class.kubernetes.io/requests.storage: 1Gi
-    bronze.storage-class.kubernetes.io/persistentvolumeclaims: 1
+    bronze.storage-class.kubernetes.io/persistentvolumeclaims: '1'
 `).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-counts'], `
 apiVersion: v1
 kind: ResourceQuota
@@ -797,4 +775,74 @@ spec:
   machineSelector:
     matchLabels:
       node-role.kubernetes.io/master: ""
+`).setIn([referenceForModel(k8sModels.MachineAutoscalerModel), 'default'], `
+apiVersion: "autoscaling.openshift.io/v1beta1"
+kind: "MachineAutoscaler"
+metadata:
+  name: "worker-us-east-1a"
+  namespace: "openshift-machine-api"
+spec:
+  minReplicas: 1
+  maxReplicas: 12
+  scaleTargetRef:
+    apiVersion: machine.openshift.io/v1beta1
+    kind: MachineSet
+    name: worker
+`).setIn([referenceForModel(k8sModels.ConsoleLinkModel), 'default'], `
+apiVersion: console.openshift.io/v1
+kind: ConsoleLink
+metadata:
+  name: example
+spec:
+  href: 'https://www.example.com'
+  location: HelpMenu
+  text: Additional help menu link
+`).setIn([referenceForModel(k8sModels.ConsoleCLIDownloadModel), 'default'], `
+apiVersion: console.openshift.io/v1
+kind: ConsoleCLIDownload
+metadata:
+  name: example
+spec:
+  displayName: examplecli
+  description: |
+    This is an example CLI download description that can include markdown such as paragraphs, unordered lists, code, [links](https://www.example.com), etc.
+
+    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce a lobortis justo, eu suscipit purus.
+  links:
+    - href: 'https://www.example.com'
+`).setIn([referenceForModel(k8sModels.ConsoleNotificationModel), 'default'], `
+apiVersion: console.openshift.io/v1
+kind: ConsoleNotification
+metadata:
+  name: example
+spec:
+  text: This is an example notification message with an optional link.
+  location: BannerTop
+  link:
+    href: 'https://www.example.com'
+    text: Optional link text
+  color: '#fff'
+  backgroundColor: '#0088ce'
+`).setIn([referenceForModel(k8sModels.ConsoleExternalLogLinkModel), 'default'], `
+apiVersion: console.openshift.io/v1
+kind: ConsoleLogLink
+metadata:
+  name: example
+spec:
+  hrefTemplate: 'https://example.com/logs?resourceName=\${resourceName}&containerName=\${containerName}&resourceNamespace=\${resourceNamespace}&podLabels=\${podLabels}'
+  text: Example Logs
 `);
+
+const pluginTemplates = ImmutableMap<GroupVersionKind, ImmutableMap<string, string>>()
+  .withMutations(map => {
+    plugins.registry.getYAMLTemplates().forEach(yt => {
+      const modelRef = referenceForModel(yt.properties.model);
+      const templateName = yt.properties.templateName || 'default';
+
+      if (!baseTemplates.hasIn([modelRef, templateName])) {
+        map.setIn([modelRef, templateName], yt.properties.template);
+      }
+    });
+  });
+
+export const yamlTemplates = baseTemplates.merge(pluginTemplates);
