@@ -29,8 +29,8 @@ export const analyticsSvc = {
     analyticsSvc.push({
       event: 'tectonicRouteChange',
       attributes: {
-        route: route,
-      }
+        route,
+      },
     });
   },
 };
