@@ -4,6 +4,18 @@ import { BuildModel, BuildConfigModel } from '../../models';
 import { k8sCreate } from './';
 import { formatDuration } from '../../components/utils/datetime';
 
+const BUILD_NUMBER_ANNOTATION = 'openshift.io/build.number';
+
+export enum BuildPhase {
+  Cancelled = 'Cancelled',
+  Complete = 'Complete',
+  Error = 'Error',
+  Failed = 'Failed',
+  New = 'New',
+  Pending ='Pending',
+  Running = 'Running',
+}
+
 const createBuildRequest = (obj, model, subresource) => {
   const req = {
     kind: 'BuildRequest',
@@ -42,3 +54,8 @@ export const formatBuildDuration = build => {
   const ms = Math.floor(duration / 1000 / 1000);
   return formatDuration(ms);
 };
+
+export const getBuildNumber = (build) => {
+  const buildNumber = _.get(build, ['metadata', 'annotations', BUILD_NUMBER_ANNOTATION]);
+  return !!buildNumber && parseInt(buildNumber, 10);
+};
