@@ -1,12 +1,10 @@
-/* eslint-disable no-unused-vars */
-
 import * as _ from 'lodash-es';
 
 import { K8sResourceKindReference, GroupVersionKind, CustomResourceDefinitionKind, K8sResourceKind, K8sKind, OwnerReference } from './index';
 
 export const getQN: (obj: K8sResourceKind) => string = ({metadata: {name, namespace}}) => (namespace ? `(${namespace})-` : '') + name;
 
-export const k8sBasePath = `${(window as any).SERVER_FLAGS.basePath}api/kubernetes`;
+export const k8sBasePath = `${window.SERVER_FLAGS.basePath}api/kubernetes`;
 
 // TODO(alecmerdler): Replace all manual string building with this function
 export const referenceForGroupVersionKind = (group: string) => (version: string) => (kind: string) => [group, version, kind].join('~');
@@ -34,6 +32,8 @@ export const kindForReference = (ref: K8sResourceKindReference) => isGroupVersio
   ? ref.split('~')[2]
   : ref;
 
+export const apiGroupForReference = (ref: GroupVersionKind) => ref.split('~')[0];
+
 export const versionForReference = (ref: GroupVersionKind) => ref.split('~')[1];
 
 export const apiVersionForModel = (model: K8sKind) => _.isEmpty(model.apiGroup)
@@ -43,3 +43,5 @@ export const apiVersionForModel = (model: K8sKind) => _.isEmpty(model.apiGroup)
 export const apiVersionForReference = (ref: GroupVersionKind) => isGroupVersionKind(ref)
   ? `${ref.split('~')[0]}/${ref.split('~')[1]}`
   : ref;
+
+export const nameForModel = (model: K8sKind) => [model.plural, model.apiGroup].join('.');
