@@ -1,33 +1,50 @@
 /* eslint-env node */
-/* eslint-disable no-unused-vars, no-undef */
-
 import * as webpack from 'webpack';
 import * as path from 'path';
 import * as HtmlWebpackPlugin from 'html-webpack-plugin';
 import * as ForkTsCheckerWebpackPlugin from 'fork-ts-checker-webpack-plugin';
 import * as MiniCssExtractPlugin from 'mini-css-extract-plugin';
+import * as VirtualModulesPlugin from 'webpack-virtual-modules';
+
+import { resolvePluginPackages, getActivePluginsModule } from '@console/plugin-sdk/src/codegen';
+import { Configuration as WebpackDevServerConfiguration } from 'webpack-dev-server';
+
+interface Configuration extends webpack.Configuration {
+  devServer?: WebpackDevServerConfiguration;
+}
+
+const MonacoWebpackPlugin = require('monaco-editor-webpack-plugin');
 
 const NODE_ENV = process.env.NODE_ENV;
+const HOT_RELOAD = process.env.HOT_RELOAD;
 
 /* Helpers */
 const extractCSS = new MiniCssExtractPlugin({filename: 'app-bundle.css'});
 
-const config: webpack.Configuration = {
-  entry: [
-    './polyfills.js',
-    './public/components/app.jsx',
-  ],
+const config: Configuration = {
+  entry: ['./polyfills.js', '@console/app', 'monaco-editor-core/esm/vs/editor/editor.worker.js'],
   output: {
     path: path.resolve(__dirname, 'public/dist'),
     publicPath: 'static/',
     filename: '[name]-bundle.js',
     chunkFilename: '[name]-[chunkhash].js',
   },
+  devServer: {
+    writeToDisk: true,
+    progress: true,
+    hot: HOT_RELOAD !== 'false',
+    inline: HOT_RELOAD !== 'false',
+  },
   resolve: {
     extensions: ['.glsl', '.ts', '.tsx', '.js', '.jsx'],
   },
   node: {
     fs: 'empty',
+    // eslint-disable-next-line camelcase
+    child_process: 'empty',
+    net: 'empty',
+    crypto: 'empty',
+    module: 'empty',
   },
   module: {
     rules: [
@@ -55,7 +72,7 @@ const config: webpack.Configuration = {
       },
       {
         test: /\.s?css$/,
-        exclude: /node_modules/,
+        exclude: /node_modules\/(?!(@patternfly)\/).*/,
         use: [
           {
             loader: MiniCssExtractPlugin.loader,
@@ -86,6 +103,11 @@ const config: webpack.Configuration = {
           },
         ],
       },
+      {
+        test: /\.css$/,
+        include: path.resolve(__dirname, './node_modules/monaco-editor'),
+        use: ['style-loader', 'css-loader'],
+      },
       {
         test: /\.(png|jpg|jpeg|gif|svg|woff2?|ttf|eot|otf)(\?.*$|$)/,
         loader: 'file-loader',
@@ -102,6 +124,7 @@ const config: webpack.Configuration = {
     runtimeChunk: true,
   },
   plugins: [
+    new webpack.NormalModuleReplacementPlugin(/^lodash$/, 'lodash-es'),
     new ForkTsCheckerWebpackPlugin({ checkSyntacticErrors: true }),
     new HtmlWebpackPlugin({
       filename: './tokener.html',
@@ -115,6 +138,10 @@ const config: webpack.Configuration = {
       production: NODE_ENV === 'production',
       chunksSortMode: 'none',
     }),
+    new MonacoWebpackPlugin({
+      languages: ['yaml'],
+    }),
+    new webpack.IgnorePlugin(/prettier/),
     extractCSS,
   ],
   devtool: 'cheap-module-source-map',
@@ -131,4 +158,11 @@ if (NODE_ENV === 'production') {
   config.stats = 'normal';
 }
 
+/* Console plugin support */
+config.plugins.push(
+  new VirtualModulesPlugin({
+    'node_modules/@console/active-plugins.js': getActivePluginsModule(resolvePluginPackages()),
+  }),
+);
+
 export default config;
